@@ -1,6 +1,6 @@
 // ;-*-C++-*-
 /*
- *       File name:  primaries.cc
+ *       File name:  core/primaries.cc
  *         Project:  Aghermann
  *          Author:  Andrei Zavada <johnhommer@gmail.com>
  * Initial version:  2010-04-28
@@ -12,16 +12,20 @@
  */
 
 
+#include <stdarg.h>
+#include <limits.h>
 #include <cfloat>
 #include <cstdlib>
+#include <cassert>
 #include <string>
+#include <fstream>
 #include <functional>
 #include <initializer_list>
 
 #include <ftw.h>
 
-#include "../misc.hh"
-#include "boost-config-validate.hh"
+#include "../common/misc.hh"
+#include "../common/config-validate.hh"
 #include "primaries.hh"
 #include "model.hh"
 
@@ -30,6 +34,22 @@ using namespace std;
 using namespace agh;
 
 
+agh::CRecording::CRecording( sigfile::CSource& F, int sig_no,
+			     const sigfile::SFFTParamSet& fft_params,
+			     const sigfile::SMCParamSet& mc_params)
+      : CBinnedPower (F, sig_no, fft_params),
+	CBinnedMC (F, sig_no, mc_params,
+		   fft_params.pagesize),
+	_status (0),
+	_source (F), _sig_no (sig_no)
+{
+	if ( F.signal_type(sig_no) == sigfile::SChannel::TType::eeg ) {
+		CBinnedPower::compute();
+		CBinnedMC::compute();
+	}
+}
+
+
 inline namespace {
 int
 mkdir_with_parents( const char *dir)
@@ -56,43 +76,48 @@ agh::CExpDesign::CExpDesign( const string& session_dir_,
 			     TMsmtCollectProgressIndicatorFun progress_fun)
       : _session_dir (session_dir_),
 	__id_pool (0),
+	fft_params ({30, sigfile::SFFTParamSet::TWinType::welch, .5}),
+	mc_params ({.5, .8, 1., 1.}),
 	af_dampen_window_type (sigfile::SFFTParamSet::TWinType::welch),
+	af_dampen_factor (.95),
 	config_keys_g ({
-		SValidator<double>("ctlparam.StepSize",		&ctl_params0.siman_params.step_size),
-		SValidator<double>("ctlparam.Boltzmannk",	&ctl_params0.siman_params.k,		SValidator<double>::SVFRange( DBL_MIN, 1e9)),
-		SValidator<double>("ctlparam.TInitial",		&ctl_params0.siman_params.t_initial,	SValidator<double>::SVFRange( DBL_MIN, 1e9)),
-		SValidator<double>("ctlparam.DampingMu",	&ctl_params0.siman_params.mu_t,		SValidator<double>::SVFRange( DBL_MIN, 1e9)),
-		SValidator<double>("ctlparam.TMin",		&ctl_params0.siman_params.t_min,	SValidator<double>::SVFRange( DBL_MIN, 1e9)),
-		SValidator<double>("ctlparam.ReqScoredPC",	&ctl_params0.req_percent_scored,	SValidator<double>::SVFRange( 80., 100.)),
-		SValidator<double>("fftparam.BinSize",		&fft_params.bin_size,			SValidator<double>::SVFRange( .1, 1.))
+		confval::SValidator<double>("ctlparam.StepSize",	&ctl_params0.siman_params.step_size),
+		confval::SValidator<double>("ctlparam.Boltzmannk",	&ctl_params0.siman_params.k,			confval::SValidator<double>::SVFRangeEx( DBL_MIN, 1e9)),
+		confval::SValidator<double>("ctlparam.TInitial",	&ctl_params0.siman_params.t_initial,		confval::SValidator<double>::SVFRangeEx( DBL_MIN, 1e9)),
+		confval::SValidator<double>("ctlparam.DampingMu",	&ctl_params0.siman_params.mu_t,			confval::SValidator<double>::SVFRangeEx( DBL_MIN, 1e9)),
+		confval::SValidator<double>("ctlparam.TMin",		&ctl_params0.siman_params.t_min,		confval::SValidator<double>::SVFRangeEx( DBL_MIN, 1e9)),
+		confval::SValidator<double>("ctlparam.ReqScoredPC",	&ctl_params0.req_percent_scored,		confval::SValidator<double>::SVFRangeIn( 80., 100.)),
+		confval::SValidator<double>("fftparam.BinSize",		&fft_params.binsize,				confval::SValidator<double>::SVFRangeIn( .125, 1.)),
+		confval::SValidator<double>("artifacts.DampenFactor",	&af_dampen_factor,				confval::SValidator<double>::SVFRangeIn( 0., 1.)),
+		confval::SValidator<double>("mcparam.iir_backpolate",	&mc_params.iir_backpolate,			confval::SValidator<double>::SVFRangeIn( 0., 1.)),
+		confval::SValidator<double>("mcparam.mc_gain",		&mc_params.mc_gain,				confval::SValidator<double>::SVFRangeIn( 0., 100.)),
+		confval::SValidator<double>("mcparam.f0fc",		&mc_params.f0fc,				confval::SValidator<double>::SVFRangeEx( 0., 80.)),
+		confval::SValidator<double>("mcparam.bandwidth",	&mc_params.bandwidth,				confval::SValidator<double>::SVFRangeIn( 0.125, 2.)),
 	}),
 	config_keys_d ({
-		SValidator<int>("fftparam.WelchWindowType",	(int*)&fft_params.welch_window_type,	SValidator<int>::SVFRange( 0, (int)sigfile::SFFTParamSet::TWinType::_total - 1)),
-		SValidator<int>("artifacts.DampenWindowType",	(int*)&af_dampen_window_type,		SValidator<int>::SVFRange( 0, (int)sigfile::SFFTParamSet::TWinType::_total - 1)),
-		SValidator<int>("ctlparam.ItersFixedT",		&ctl_params0.siman_params.iters_fixed_T,SValidator<int>::SVFRange( 1, 1000000)),
-		SValidator<int>("ctlparam.NTries",		&ctl_params0.siman_params.n_tries,	SValidator<int>::SVFRange( 1, 10000)),
-	}),
-	config_keys_z ({
-		SValidator<size_t>("ctlparam.NSWALadenPagesBeforeSWA0",	&ctl_params0.swa_laden_pages_before_SWA_0,	SValidator<size_t>::SVFRange( 1, 100)),
-		SValidator<size_t>("fftparam.PageSize",			&fft_params.page_size),
+		confval::SValidator<int>("fftparam.WelchWindowType",	(int*)&fft_params.welch_window_type,		confval::SValidator<int>::SVFRangeIn( 0, (int)sigfile::SFFTParamSet::TWinType::_total - 1)),
+		confval::SValidator<int>("artifacts.DampenWindowType",	(int*)&af_dampen_window_type,			confval::SValidator<int>::SVFRangeIn( 0, (int)sigfile::SFFTParamSet::TWinType::_total - 1)),
+		confval::SValidator<int>("ctlparam.ItersFixedT",	&ctl_params0.siman_params.iters_fixed_T,	confval::SValidator<int>::SVFRangeIn( 1, 1000000)),
+		confval::SValidator<int>("ctlparam.NTries",		&ctl_params0.siman_params.n_tries,		confval::SValidator<int>::SVFRangeIn( 1, 10000)),
+		confval::SValidator<int>("ctlparam.NSWALadenPagesBeforeSWA0",	(int*)&ctl_params0.swa_laden_pages_before_SWA_0,	confval::SValidator<size_t>::SVFRangeIn( 1, 100)),
+		confval::SValidator<int>("fftparam.PageSize",			(int*)&fft_params.pagesize,				confval::SValidator<size_t>::SVFRangeIn( 4, 120)),
 	}),
 	config_keys_b ({
-		SValidator<bool>("ctlparam.DBAmendment1",		&ctl_params0.DBAmendment1),
-		SValidator<bool>("ctlparam.DBAmendment2",		&ctl_params0.DBAmendment2),
-		SValidator<bool>("ctlparam.AZAmendment1",		&ctl_params0.AZAmendment1),
-		SValidator<bool>("ctlparam.AZAmendment2",		&ctl_params0.AZAmendment2),
-		SValidator<bool>("ctlparam.ScoreMVTAsWake",		&ctl_params0.ScoreMVTAsWake),
-		SValidator<bool>("ctlparam.ScoreUnscoredAsWake",	&ctl_params0.ScoreUnscoredAsWake),
+		confval::SValidator<bool>("ctlparam.DBAmendment1",		&ctl_params0.DBAmendment1),
+		confval::SValidator<bool>("ctlparam.DBAmendment2",		&ctl_params0.DBAmendment2),
+		confval::SValidator<bool>("ctlparam.AZAmendment1",		&ctl_params0.AZAmendment1),
+		confval::SValidator<bool>("ctlparam.AZAmendment2",		&ctl_params0.AZAmendment2),
+		confval::SValidator<bool>("ctlparam.ScoreUnscoredAsWake",	&ctl_params0.ScoreUnscoredAsWake),
 	})
 {
       // ensure this
 	// if ( _session_dir.back() == '/' )
 	// 	_session_dir.pop_back();
-	if ( _session_dir[_session_dir.size()-1] == '/' )
+	if ( _session_dir.size() > 0 && _session_dir[_session_dir.size()-1] == '/' )
 		_session_dir.erase( _session_dir.size()-1, 1);
 
 	if ( chdir( session_dir()) == -1 ) {
-		printf( "CExpDesign::CExpDesign(): Could not cd to \"%s\"; trying to create a new directory there...", session_dir());
+		printf( "CExpDesign::CExpDesign(): Could not cd to \"%s\"; trying to create a new diretory there...", session_dir());
 		if ( mkdir_with_parents( session_dir()) || chdir( session_dir()) != -1 )
 			printf( "done\n");
 		else {
@@ -107,8 +132,25 @@ agh::CExpDesign::CExpDesign( const string& session_dir_,
 }
 
 
+void
+agh::CExpDesign::
+log_message( const char* fmt, ...)
+{
+	va_list ap;
+	va_start (ap, fmt);
 
+	DEF_UNIQUE_CHARP(buf);
+	assert (vasprintf( &buf, fmt, ap) > 0);
 
+	_error_log += buf;
+	if ( strlen(buf) && *(buf + strlen(buf)-1) != '\n' ) {
+		_error_log += "\n";
+		fprintf( stderr, "%s\n", buf);
+	} else
+		fputs( buf, stderr);
+
+	va_end (ap);
+}
 
 
 
@@ -163,10 +205,6 @@ list<sigfile::SChannel>
 agh::CExpDesign::enumerate_eeg_channels() const
 {
 	list<sigfile::SChannel> recp;
-// 	list<sigfile::SChannel> recp = enumerate_all_channels();
-// 	recp.remove_if(
-// //		bind( sigfile::SChannel::channel_is_fftable, _1));
-// 		[] ( const sigfile::SChannel& H) { return not sigfile::SChannel::channel_is_fftable(H); });
 /// sigfile::SChannel will rightly not count oddly named channels
 /// which, still, were additionally qualified as EEG in the EDF
 /// header, so we'd better walk it again and look at signal type
@@ -202,14 +240,51 @@ agh::CExpDesign::enumerate_all_channels() const
 }
 
 
+list<size_t>
+agh::CExpDesign::used_samplerates( sigfile::SChannel::TType type) const
+{
+	list<size_t> recp;
+	for ( auto &G : groups )
+		for ( auto &J : G.second )
+			for ( auto &D : J.measurements )
+				for ( auto &E : D.second.episodes )
+					for ( auto &F : E.sources )
+						for ( size_t h = 0; h < F.n_channels(); ++h )
+							if ( type == sigfile::SChannel::other or
+							     type == F.signal_type(h) ) {
+								recp.push_back( F.samplerate(h));
+							}
+	recp.sort();
+	recp.unique();
+	return recp;
+}
 
 
+
+const char*
+agh::CSubject::gender_sign( TGender g)
+{
+	switch ( g ) {
+	case TGender::male:
+		return "M";
+	case TGender::female:
+		return "F";
+	case TGender::neuter:
+		return "o";
+	default:
+		return "??";
+	}
+}
+
 agh::CSubject::CSubject( const string& dir,
 			 sid_type id)
   : _status (0),
     _id (id),
     _dir (dir),
-    _name (dir.substr( dir.rfind('/')+1))
+    _name (dir.substr( dir.rfind('/')+1)),
+    full_name (_name),
+    gender (TGender::neuter),
+    age (-1)
 {
 	ifstream ifs (_dir + "/.subject_info");
 	char gender_char;
@@ -219,12 +294,6 @@ agh::CSubject::CSubject( const string& dir,
 	      getline( ifs, comment, '\n'),
 	      ifs.good()) )
 		gender = (TGender)gender_char;
-	else {
-		full_name = _name;
-		gender = TGender::neuter;
-		age = 21;
-		comment = "fafa";
-	}
 }
 
 
@@ -244,23 +313,21 @@ agh::CSubject::~CSubject()
 
 
 
-#define AGH_EPSEQADD_OVERLAP -1
-#define AGH_EPSEQADD_TOOFAR  -2
-
 
 agh::CSubject::SEpisode::SEpisode( sigfile::CSource&& Fmc,
-				   const sigfile::SFFTParamSet& fft_params)
+				   const sigfile::SFFTParamSet& fft_params,
+				   const sigfile::SMCParamSet& mc_params)
 {
       // move it in place
-	// printf( "CSubject::SEpisode::SEpisode( file: \"%s\", type: %d, J: \"%s\", E: \"%s\", D: \"%s\")\n",
-	// 	 Fmc.filename(), (int)Fmc.type(), Fmc.subject(), Fmc.episode(), Fmc.session());
-	sources.emplace_back( static_cast<sigfile::CSource&&>(Fmc));
+	sources.emplace_back( move(Fmc));
 	auto& F = sources.back();
 	auto HH = F.channel_list();
+	printf( "CSubject::SEpisode::SEpisode( \"%s\"): %s\n",
+		F.filename(), string_join(HH, ", ").c_str());
 	int h = 0;
 	for ( auto &H : HH )
 		recordings.insert(
-			{H, CRecording (F, h++, fft_params)});
+			{H, CRecording (F, h++, fft_params, mc_params)});
 }
 
 
@@ -284,12 +351,15 @@ agh::CSubject::SEpisode::get_annotations() const
 
 
 
-
-
+#define AGH_EPSEQADD_OVERLAP -1
+#define AGH_EPSEQADD_TOOFAR  -2
 
 int
-agh::CSubject::SEpisodeSequence::add_one( sigfile::CSource&& Fmc, const sigfile::SFFTParamSet& fft_params,
-					  float max_hours_apart)
+agh::CSubject::SEpisodeSequence::
+add_one( sigfile::CSource&& Fmc,
+	 const sigfile::SFFTParamSet& fft_params,
+	 const sigfile::SMCParamSet& mc_params,
+	 float max_hours_apart)
 {
 	auto Ei = find( episodes.begin(), episodes.end(),
 			Fmc.episode());
@@ -310,13 +380,15 @@ agh::CSubject::SEpisodeSequence::add_one( sigfile::CSource&& Fmc, const sigfile:
 		     fabs( difftime( episodes.begin()->sources.begin()->start_time(), Fmc.start_time())) / 3600 > max_hours_apart )
 			return AGH_EPSEQADD_TOOFAR;
 
-		printf( "CSubject::SEpisodeSequence::add_one( file: \"%s\", J: \"%s\", E: \"%s\", D: \"%s\")\n",
-			Fmc.filename(), Fmc.subject(), Fmc.episode(), Fmc.session());
-		episodes.emplace_back( static_cast<sigfile::CSource&&>(Fmc), fft_params);
+		printf( "CSubject::SEpisodeSequence::add_one( \"%s\")\n",
+			Fmc.filename());
+		episodes.emplace_back( move(Fmc), fft_params, mc_params);
 		episodes.sort();
 
 	} else { // same as SEpisode() but done on an existing one
 	      // check that the edf source being added has exactly the same timestamp and duration
+		printf( "CSubject::SEpisodeSequence::add_one( \"%s\") try in-place\n",
+			Fmc.filename());
 		if ( fabs( difftime( Ei->start_time(), Fmc.start_time())) > 1 )
 			return AGH_EPSEQADD_TOOFAR;
 		Ei->sources.emplace_back( static_cast<sigfile::CSource&&>(Fmc));
@@ -325,7 +397,7 @@ agh::CSubject::SEpisodeSequence::add_one( sigfile::CSource&& Fmc, const sigfile:
 		int h = 0;
 		for ( auto &H : HH )
 			Ei->recordings.insert(
-				{H, {F, h++, fft_params}});
+				{H, {F, h++, fft_params, mc_params}});
 		// no new episode added: don't sort
 	}
 
@@ -375,64 +447,83 @@ agh::CExpDesign::register_intree_source( sigfile::CSource&& F,
 					 const char **reason_if_failed_p)
 {
 	try {
-//		CEDFFile F (fname, fft_params.page_size);
 	      // parse fname (as appearing in the right place in the
 	      // tree) as ./group/subject/session/episode.edf
-	      // (We couldn't make life easier for us by passing these
-	      // as parameters due to us being called from nftw()).
+	      // in order to validate this source wrt its placement in the tree
 		string toparse (F.filename());
 		if ( strncmp( F.filename(), _session_dir.c_str(), _session_dir.size()) == 0 )
 			toparse.erase( 0, _session_dir.size());
-		const char
-			*g_name = strtok(&toparse[2], "/"),  // skip "./"
-			*j_id   = strtok(NULL, "/"),
-			*d_name = strtok(NULL, "/");
-			//*e_name = F.Episode.c_str();  // except for this, which if of the form episode-1.edf,
-							// will still result in 'episode' (handled in CEDFFile(fname))
-			// all handled in add_one
-		if ( strcmp( F.subject(), j_id) != 0 ) {
-			fprintf( stderr, "CExpDesign::register_intree_source(\"%s\"): file belongs to subject \"%s\", is misplaced here (\"%s\")\n",
-				 F.filename(), F.subject(), j_id);
+		list<string> broken_path = fs::path_elements( toparse);
+		assert ( broken_path.size() == 5 );
+		list<string>::iterator pe = broken_path.begin();
+		string& g_name = (pe = next(pe), *pe),
+			j_name = (pe = next(pe), *pe),
+			d_name = (pe = next(pe), *pe),
+			e_name = fs::make_fname_base(*next(pe), ".edf", false);
+		// take care of the case of episode-2.edf
+		if ( e_name.size() >= 3 /* strlen("a-1") */ ) {
+			size_t sz = e_name.size();
+			if ( e_name[sz-2] == '-' && isdigit(e_name[sz-1]) )
+				e_name.erase( sz-2, 2);
+		}
+
+		// refuse to register sources of wrong subjects
+		if ( j_name != F.subject() ) {
+			log_message( "%s: file belongs to subject \"%s\", is misplaced here under subject \"%s\"\n",
+				     F.filename(), F.subject(), j_name.c_str());
 			return -1;
 		}
-		if ( strcmp( F.session(), d_name) != 0 ) {
-			printf( "CExpDesign::register_intree_source(\"%s\"): embedded session identifier \"%s\" does not match its session as placed in the tree; using \"%s\"\n",
-				F.filename(), F.session(), d_name);
-			F.set_session( d_name);
+		try {
+			auto existing_group = group_of( F.subject());
+			if ( g_name != existing_group ) {
+				log_message( "%s: subject \"%s\" belongs to a different group (\"%s\")\n",
+					     F.filename(), F.subject(), existing_group);
+				return -1;
+			}
+		} catch (invalid_argument) {
+			;
+		}
+
+		// but correct session/episode fields
+		if ( d_name != F.session() ) {
+			log_message( "%s: correcting embedded session \"%s\" to match placement in the tree (\"%s\")\n",
+				     F.filename(), F.session(), d_name.c_str());
+			F.set_session( d_name.c_str());
+		}
+		if ( e_name != F.episode() ) {
+			log_message( "%s: correcting embedded episode \"%s\" to match file name\n",
+				     F.filename(), F.episode());
+			F.set_episode( e_name.c_str());
 		}
 
 		CSubject *J;
 		CJGroup& G = groups[g_name];
 		CJGroup::iterator Ji;
-		if ( (Ji = find( G.begin(), G.end(), j_id)) == G.end() ) {
-			G.emplace_back( _session_dir + '/' + g_name + '/' + j_id, __id_pool++);
+		if ( (Ji = find( G.begin(), G.end(), j_name)) == G.end() ) {
+			G.emplace_back( _session_dir + '/' + g_name + '/' + j_name, __id_pool++);
 			J = &G.back();
 		} else
 			J = &*Ji;
 
 	      // insert/update episode observing start/end times
-		// printf( "CExpDesign::register_intree_source( file: \"%s\", J: \"%s\", E: \"%s\", D: \"%s\")\n",
+		// printf( "\nCExpDesign::register_intree_source( file: \"%s\", J: \"%s\", E: \"%s\", D: \"%s\")\n",
 		// 	   F.filename(), F.subject(), F.episode(), F.session());
 		switch ( J->measurements[F.session()].add_one(
-				 (sigfile::CSource&&)F, fft_params) ) {  // this will do it
+				 (sigfile::CSource&&)F, fft_params, mc_params) ) {  // this will do it
 		case AGH_EPSEQADD_OVERLAP:
-			fprintf( stderr, "CExpDesign::register_intree_source(\"%s\"): not added as it overlaps with existing episodes\n",
-				 F.filename());
-			log_message( string(F.filename()) + " not added as it overlaps with existing episodes\n");
+			log_message( "CExpDesign::register_intree_source(\"%s\"): not added as it overlaps with existing episodes\n",
+				     F.filename());
 			return -1;
 		case AGH_EPSEQADD_TOOFAR:
-			fprintf( stderr, "CExpDesign::register_intree_source(\"%s\"): not added as it is too far removed from the rest\n",
-				 F.filename());
-			log_message( string(F.filename()) + " not added as it is too far removed from the rest\n");
+			log_message( "CExpDesign::register_intree_source(\"%s\"): not added as it is too far removed from the rest\n",
+				     F.filename());
 			return -1;
 		default:
 			return 0;
 		}
-//		printf( "CExpDesign::register_intree_source(\"%s\"): ok\n", toparse());
 
 	} catch (invalid_argument ex) {
 		log_message( ex.what() + '\n');
-		fprintf( stderr, "CExpDesign::register_intree_source(\"%s\") failed: %s\n", F.filename(), ex.what());
 		if ( reason_if_failed_p )
 			*reason_if_failed_p = ex.what();
 		return -1;
@@ -483,20 +574,15 @@ edf_file_processor( const char *fname, const struct stat *st, int flag, struct F
 			++__cur_edf_file;
 			only_progress_fun( fname, __n_edf_files, __cur_edf_file);
 			try {
-				sigfile::CSource f_tmp {fname, __expdesign->fft_params.page_size};
+				sigfile::CSource f_tmp {fname, __expdesign->fft_params.pagesize};
 				string st = f_tmp.explain_status();
-				if ( st.size() )
-					__expdesign->log_message( string (fname) + ":\n"+ st + '\n');
+				if ( not st.empty() )
+					__expdesign->log_message( "%s: %s\n", fname, st.c_str());
 				if ( __expdesign -> register_intree_source( (sigfile::CSource&&)f_tmp) )
 					;
 
 			} catch ( invalid_argument ex) {
-				DEF_UNIQUE_CHARP (_);
-				if ( asprintf( &_, "collect_msmts_from_tree(): edf source \"%s\" could not be read (%s)\n",
-					       fname, ex.what()) )
-					;
-				fprintf( stderr, "%s", _);
-				__expdesign->log_message(_);
+				__expdesign->log_message(ex.what());
 			}
 		}
 	}
@@ -538,16 +624,14 @@ agh::CExpDesign::scan_tree( TMsmtCollectProgressIndicatorFun user_progress_fun)
 
 	for ( auto &G : groups )
 		for ( auto &J : G.second )
+		startover:
 			for ( auto &D : J.measurements )
 				if ( D.second.episodes.size() < n_episodes &&
-				     *complete_episode_set.begin() != D.second.episodes.begin()->name() ) { // the baseline is missing
-					fprintf( stderr,
-						 "No Baseline episode in %s's %s: skip this session\n",
-						 J.name(), D.first.c_str());
-					log_message( string("Missing Baseline episode in ") + D.first + " for "
-						     + G.first + '/' + J.name()
-						     + ": skipping this session\n");
+				     complete_episode_set.front() != D.second.episodes.begin()->name() ) { // the baseline is missing
+					log_message( "No Baseline episode in %s's %s: skip this session\n",
+						     J.name(), D.first.c_str());
 					J.measurements.erase(D.first);
+					goto startover;
 				}
 
 	list<string> complete_session_set = enumerate_sessions();
@@ -595,23 +679,24 @@ agh::CExpDesign::remove_untried_modruns()
 		for ( auto &J : G.second )
 			for ( auto &D : J.measurements )
 			retry_modruns:
-				for ( auto RSi = D.second.modrun_sets.begin(); RSi != D.second.modrun_sets.end(); ++RSi ) {
-				retry_this_modrun_set:
-					for ( auto Ri = RSi->second.begin(); Ri != RSi->second.end(); ++Ri ) {
-						// printf( "#----- check Subject: %s;  Session: %s;  Channel: %s;  Range: %g-%g Hz (%d)\n",
-						// 	Ri->second.subject(), Ri->second.session(), Ri->second.channel(),
-						// 	Ri->second.freq_from(), Ri->second.freq_upto(),
-						// 	Ri->second.status);
-						if ( !(Ri->second.status & CModelRun::modrun_tried) ) {
-							RSi->second.erase( Ri);
-							goto retry_this_modrun_set;
+				for ( auto RSt = D.second.modrun_sets.begin(); RSt != D.second.modrun_sets.end(); ++RSt )
+					for ( auto RSi = RSt->second.begin(); RSi != RSt->second.end(); ++RSi ) {
+					retry_this_modrun_set:
+						for ( auto Ri = RSi->second.begin(); Ri != RSi->second.end(); ++Ri ) {
+							// printf( "#----- check Subject: %s;  Session: %s;  Channel: %s;  Range: %g-%g Hz (%d)\n",
+							// 	Ri->second.subject(), Ri->second.session(), Ri->second.channel(),
+							// 	Ri->second.freq_from(), Ri->second.freq_upto(),
+							// 	Ri->second.status);
+							if ( !(Ri->second.status & CModelRun::modrun_tried) ) {
+								RSi->second.erase( Ri);
+								goto retry_this_modrun_set;
+							}
+						}
+						if ( RSi->second.empty() ) {
+							D.second.modrun_sets.erase( RSt);
+							goto retry_modruns;
 						}
 					}
-					if ( RSi->second.empty() ) {
-						D.second.modrun_sets.erase( RSi);
-						goto retry_modruns;
-					}
-				}
 }
 
 void
@@ -641,17 +726,18 @@ agh::CExpDesign::export_all_modruns( const string& fname) const
 		for ( auto &J : G.second )
 			for ( auto &D : J.measurements )
 				for ( auto &RS : D.second.modrun_sets )
-					for ( auto &R : RS.second )
-						if ( R.second.status & CModelRun::modrun_tried ) {
-							fprintf( f, "# ----- Subject: %s;  Session: %s;  Channel: %s;  Range: %g-%g Hz\n",
-								 R.second.subject(), R.second.session(), R.second.channel(),
-								 R.second.freq_from(), R.second.freq_upto());
-							t = TTunable::rs;
-							do {
-								fprintf( f, "%g%s", R.second.cur_tset[t] * STunableSet::stock[t].display_scale_factor,
-									 (t < R.second.cur_tset.last()) ? "\t" : "\n");
-							} while ( t++ < R.second.cur_tset.last() );
-						}
+					for ( auto &Q : RS.second )
+						for ( auto &R : Q.second )
+							if ( R.second.status & CModelRun::modrun_tried ) {
+								fprintf( f, "# ----- Subject: %s;  Session: %s;  Channel: %s;  Range: %g-%g Hz\n",
+									 R.second.subject(), R.second.session(), R.second.channel(),
+									 R.second.freq_from(), R.second.freq_upto());
+								t = TTunable::rs;
+								do {
+									fprintf( f, "%g%s", R.second.cur_tset[t] * STunableSet::stock[t].display_scale_factor,
+										 (t < R.second.cur_tset.last()) ? "\t" : "\n");
+								} while ( t++ < R.second.cur_tset.last() );
+							}
 
 	fclose( f);
 }
