@@ -13,15 +13,17 @@
 
 #include <sys/stat.h>
 #include <sys/mman.h>
+#include <unistd.h>
 #include <fcntl.h>
 #include <cerrno>
 #include <memory>
 #include <fstream>
-#include <sstream>
+#include <list>
 #include <stdexcept>
 #include <iterator>
 
-#include "../misc.hh"
+#include "../common/misc.hh"
+#include "../common/string.hh"
 #include "edf.hh"
 #include "source.hh"
 
@@ -142,16 +144,6 @@ sigfile::CEDFFile::CEDFFile( const char *fname, int flags)
 		ifstream thomas (make_fname_artifacts( H.channel));
 		if ( not thomas.good() )
 			continue;
-		int wt = -1;
-		float fac = 0.;
-		thomas >> wt >> fac;
-		if ( thomas.eof()
-		     || wt < 0 || wt > (int)SFFTParamSet::TWinType::welch
-		     || fac == 0. ) {
-			continue;
-		}
-		H.artifacts.dampen_window_type = (SFFTParamSet::TWinType)wt;
-		H.artifacts.factor = fac;
 
 		while ( !thomas.eof() ) {
 			size_t aa = (size_t)-1, az = (size_t)-1;
@@ -254,7 +246,6 @@ sigfile::CEDFFile::write_ancillary_files()
 		if ( I.artifacts().size() ) {
 			ofstream thomas (make_fname_artifacts( I.channel), ios_base::trunc);
 			if ( thomas.good() ) {
-				thomas << (unsigned short)I.artifacts.dampen_window_type << ' ' << I.artifacts.factor << endl;
 				for ( auto &A : I.artifacts() )
 					thomas << A.first << ' ' << A.second << endl;
 			}
@@ -352,10 +343,10 @@ sigfile::CEDFFile::_parse_header()
 			char int_session[81], int_episode[81];
 			string rec_id_isolated (strtrim( string (header.recording_id, 80)));
 #define T "%80[-a-zA-Z0-9 _]"
-			if ( sscanf( rec_id_isolated.c_str(), T", "T,    int_episode, int_session) == 2 ||
-			     sscanf( rec_id_isolated.c_str(), T": "T,    int_session, int_episode) == 2 ||
-			     sscanf( rec_id_isolated.c_str(), T"/"T,     int_session, int_episode) == 2 ||
-			     sscanf( rec_id_isolated.c_str(), T" ("T")", int_session, int_episode) == 2 )
+			if ( sscanf( rec_id_isolated.c_str(), T ", " T,     int_episode, int_session) == 2 ||
+			     sscanf( rec_id_isolated.c_str(), T ": " T,     int_session, int_episode) == 2 ||
+			     sscanf( rec_id_isolated.c_str(), T "/"  T,     int_session, int_episode) == 2 ||
+			     sscanf( rec_id_isolated.c_str(), T " (" T ")", int_session, int_episode) == 2 )
 				;
 			else
 				_status |= (nosession | noepisode);
@@ -376,7 +367,7 @@ sigfile::CEDFFile::_parse_header()
 
 			if ( _status & noepisode ) { // (a) failed
 				_episode.assign( fn_episode);    // use RecordingID_raw as Session
-				_session.assign( rec_id_isolated.c_str());
+				_session.assign( rec_id_isolated);
 			} else {
 				_episode.assign( int_episode);
 				_session.assign( int_session);
@@ -388,13 +379,15 @@ sigfile::CEDFFile::_parse_header()
 			char *p;
 			//memset( &ts, 0, sizeof(struct tm));
 			ts.tm_isdst = 0;  // importantly
-			p = strptime( string (header.recording_date, 8).c_str(), "%d.%m.%y", &ts);
+			string tmp (header.recording_date, 8);
+			p = strptime( tmp.c_str(), "%d.%m.%y", &ts);
 			if ( p == NULL || *p != '\0' ) {
 				_status |= date_unparsable;
 				if ( not (flags() & no_field_consistency_check) )
 					return -2;
 			}
-			p = strptime( string (header.recording_time, 8).c_str(), "%H.%M.%S", &ts);
+			tmp = {string (header.recording_time, 8)};
+			p = strptime( tmp.c_str(), "%H.%M.%S", &ts);
 			if ( p == NULL || *p != '\0' ) {
 				_status |= time_unparsable;
 				if ( not (flags() & no_field_consistency_check) )
@@ -474,10 +467,10 @@ sigfile::CEDFFile::_parse_header()
 
 			for ( auto &H : signals ) {
 				char *tail;
+				string t {strtrim( string (_get_next_field( H.header.samples_per_record, 8), 8))};
 				H.samples_per_record =
-					strtoul( strtrim( string (_get_next_field( H.header.samples_per_record, 8), 8)).c_str(),
-						 &tail, 10);
-				if ( *tail != '\0' ) {
+					strtoul( t.c_str(), &tail, 10);
+				if ( tail == NULL || *tail != '\0' ) {
 					_status |= bad_numfld;
 					if ( not (flags() & no_field_consistency_check) )
 						return -2;
@@ -638,33 +631,33 @@ sigfile::CEDFFile::details( bool channels_too) const
 string
 sigfile::CEDFFile::explain_edf_status( int status)
 {
-	ostringstream recv;
+	list<string> recv;
 	if ( status & bad_header )
-		recv << "* Ill-formed header\n";
+		recv.emplace_back( "* Ill-formed header");
 	if ( status & bad_version )
-		recv << "* Bad Version signature (i.e., not an EDF file)\n";
+		recv.emplace_back( "* Bad Version signature (i.e., not an EDF file)");
 	if ( status & bad_numfld )
-		recv << "* Garbage in numerical fields\n";
+		recv.emplace_back( "* Garbage in numerical fields");
 	if ( status & date_unparsable )
-		recv << "* Date field ill-formed\n";
+		recv.emplace_back( "* Date field ill-formed");
 	if ( status & time_unparsable )
-		recv << "* Time field ill-formed\n";
+		recv.emplace_back( "* Time field ill-formed");
 	if ( status & nosession )
-		recv << "* No session information in field RecordingID "
+		recv.emplace_back(
+			"* No session information in field RecordingID "
 			"(expecting this to appear after "
-			"episode designation followed by a comma)\n";
+			"episode designation followed by a comma)");
 	if ( status & non1020_channel )
-		recv << "* Channel designation not following the 10-20 system\n";
+		recv.emplace_back( "* Channel designation not following the 10-20 system");
 	if ( status & nonkemp_signaltype )
-		recv << "* Signal type not listed in Kemp et al\n";
+		recv.emplace_back( "* Signal type not listed in Kemp et al");
 	if ( status & dup_channels )
-		recv << "* Duplicate channel names\n";
+		recv.emplace_back( "* Duplicate channel names");
 	if ( status & nogain )
-		recv << "* Physical or Digital Min value greater than Max\n";
+		recv.emplace_back( "* Physical or Digital Min value greater than Max");
 	if ( status & too_many_signals )
-		recv << "* Number of signals grearter than " << max_signals << "\n";
-
-	return recv.str();
+		recv.emplace_back( string("* Number of signals grearter than ") + to_string(max_signals));
+	return string_join(recv, "\n");
 }
 
 
