@@ -18,6 +18,8 @@ using namespace std;
 void
 sigfile::SArtifacts::mark_artifact( size_t aa, size_t az)
 {
+	if ( aa >= az )
+		return;
 	obj.emplace_back( aa, az);
 	obj.sort();
 startover:
@@ -36,7 +38,7 @@ sigfile::SArtifacts::clear_artifact( size_t aa, size_t az)
 {
 startover:
 	for ( auto A = obj.begin(); A != obj.end(); ++A ) {
-		if ( aa < A->first && A->second < az ) {
+		if ( aa <= A->first && A->second <= az ) {
 			obj.erase( A);
 			goto startover;
 		}
@@ -55,7 +57,7 @@ startover:
 }
 
 
-hash_t
+agh::hash_t
 sigfile::SArtifacts::dirty_signature() const
 {
 	string sig ("a");
