@@ -21,7 +21,7 @@
 #include <iostream>
 #include "../libsigfile/edf.hh"
 #include "../libsigfile/source.hh"
-#include "../fs.hh"
+#include "../common/fs.hh"
 
 #include "config.h"
 
@@ -205,7 +205,7 @@ parse_opt( int key, char *arg, struct argp_state *state)
 	default:
 		return (error_t)ARGP_ERR_UNKNOWN;
 	}
-	return 0;
+	return (error_t)0;
 }
 
 
