@@ -11,17 +11,39 @@
  */
 
 
+#include <libconfig.h++>
+
 #include <unistd.h>
 #include "misc.hh"
 #include "expdesign.hh"
 
-#include <boost/property_tree/ptree.hpp>
-#include <boost/property_tree/xml_parser.hpp>
-
 using namespace std;
 using namespace aghui;
 
 
+void
+aghui::SExpDesignUI::
+buf_on_chooser_status_bar( bool ensure)
+{
+	gtk_statusbar_pop( sbExpDesignChooserStatusBar, sbChooserContextIdGeneral);
+	gtk_statusbar_push( sbExpDesignChooserStatusBar, sbChooserContextIdGeneral, __buf__);
+	/// segfaults no matter what. Cannot call gtk_events_pending() from a handler.
+	// if ( ensure ) {
+	//  	g_signal_handler_block( bExpDesignChooserSelect, bExpDesignChooserSelect_clicked_cb_handler);
+	//   	aghui::gtk_flush();
+	//  	g_signal_handler_unblock( bExpDesignChooserSelect, bExpDesignChooserSelect_clicked_cb_handler);
+	// }
+}
+
+void
+aghui::SExpDesignUI::
+sb_chooser_progress_indicator( const char* current, size_t n, size_t i)
+{
+	snprintf_buf( "(%zu of %zu) %s", i, n, current);
+	buf_on_chooser_status_bar( true);
+}
+
+
 
 string
 aghui::SExpDesignUI::chooser_get_selected_dir()
@@ -43,7 +65,6 @@ aghui::SExpDesignUI::chooser_get_selected_dir()
 	tilda2homedir(ret);
 	g_free(entry);
 	gtk_tree_path_free( path);
-	printf( "entry: %s\n", ret.c_str());
 	return ret;
 }
 
@@ -77,14 +98,14 @@ aghui::SExpDesignUI::chooser_get_dir( int idx)
 void
 aghui::SExpDesignUI::chooser_read_histfile()
 {
-	using boost::property_tree::ptree;
-	ptree pt;
+	libconfig::Config conf;
 
 	GtkTreeIter iter;
 	try {
-		read_xml( chooser.hist_filename, pt);
-		chooser.last_dir_no = pt.get<int>( "Sessions.Last");
-		string entries_ = pt.get<string>( "Sessions.List");
+		conf.readFile( chooser.hist_filename.c_str());
+		conf.lookupValue( "SessionLast", chooser.last_dir_no);
+		string entries_;
+		conf.lookupValue( "SessionList", entries_);
 
 		list<string> entries {string_tokens( &entries_[0], ";")};
 		gtk_list_store_clear( mExpDesignChooserList);
@@ -138,16 +159,19 @@ aghui::SExpDesignUI::chooser_write_histfile()
 		some_items_left = gtk_tree_model_iter_next( (GtkTreeModel*)mExpDesignChooserList, &iter);
 	}
 
-	using boost::property_tree::ptree;
-	ptree pt;
-	pt.put( "Sessions.List", agg);
-	pt.put( "Sessions.Last", chooser.last_dir_no);
+	try {
+		libconfig::Config conf;
+		conf.getRoot().add( "SessionList", libconfig::Setting::Type::TypeString) = agg;
+		conf.getRoot().add( "SessionLast", libconfig::Setting::Type::TypeInt) = chooser.last_dir_no;
 
-	gchar *dirname = g_path_get_dirname( chooser.hist_filename.c_str());
-	g_mkdir_with_parents( dirname, 0755);
-	g_free( dirname);
+		gchar *dirname = g_path_get_dirname( chooser.hist_filename.c_str());
+		g_mkdir_with_parents( dirname, 0755);
+		g_free( dirname);
 
-	write_xml( chooser.hist_filename, pt);
+		conf.writeFile( chooser.hist_filename.c_str());
+	} catch (...) {
+		pop_ok_message( (GtkWindow*)wExpDesignChooser, "Couldn't write %s", chooser.hist_filename.c_str());
+	}
 }
 
 
