@@ -64,7 +64,8 @@ aghui::SExpDesignUI::construct_widgets()
 	     !AGH_GBGETOBJ (GtkMenuItem,	iMontageNotchNone) ||
 	     !AGH_GBGETOBJ (GtkMenuItem,	iMontageNotch50Hz) ||
 	     !AGH_GBGETOBJ (GtkMenuItem,	iMontageNotch60Hz) ||
-	     !AGH_GBGETOBJ (GtkMenuItem,	iHelpAbout) )
+	     !AGH_GBGETOBJ (GtkMenuItem,	iHelpAbout) ||
+	     !AGH_GBGETOBJ (GtkMenuItem,	iHelpUsage) )
 		return -1;
 
 	g_signal_connect( iExpChange, "activate",
@@ -82,6 +83,9 @@ aghui::SExpDesignUI::construct_widgets()
 	g_signal_connect( iHelpAbout, "activate",
 			  (GCallback)iHelpAbout_activate_cb,
 			  this);
+	g_signal_connect( iHelpUsage, "activate",
+			  (GCallback)iHelpUsage_activate_cb,
+			  this);
 
 	g_signal_connect( iMontageResetAll, "activate",
 			  (GCallback)iMontageResetAll_activate_cb,
@@ -98,7 +102,7 @@ aghui::SExpDesignUI::construct_widgets()
 
 	if ( !AGH_GBGETOBJ (GtkWindow,		wMainWindow) ||
 	     !AGH_GBGETOBJ (GtkVBox,		cMeasurements) ||
-	     !AGH_GBGETOBJ (GtkLabel,		lMsmtInfo) )
+	     !AGH_GBGETOBJ (GtkLabel,		lMsmtPSDInfo) )
 		return -1;
 
 	wMainWindow_delete_event_cb_handler_id =
@@ -110,13 +114,12 @@ aghui::SExpDesignUI::construct_widgets()
 			  this);
 
 	g_signal_connect( cMeasurements, "drag-data-received",
-			  (GCallback)cMeasurements_drag_data_received_cb,
+			  (GCallback)common_drag_data_received_cb,
 			  this);
 	g_signal_connect( cMeasurements, "drag-drop",
-			  (GCallback)cMeasurements_drag_drop_cb,
+			  (GCallback)common_drag_drop_cb,
 			  this);
 
-
 	gtk_drag_dest_set( (GtkWidget*)cMeasurements, GTK_DEST_DEFAULT_ALL,
 			   NULL, 0, GDK_ACTION_COPY);
 	gtk_drag_dest_add_uri_targets( (GtkWidget*)(cMeasurements));
@@ -213,19 +216,39 @@ aghui::SExpDesignUI::construct_widgets()
 					"text", 0,
 					NULL);
 
-     // ------------- eMsmtPSDFreq
-	if ( !AGH_GBGETOBJ (GtkSpinButton,	eMsmtPSDFreqFrom) ||
-	     !AGH_GBGETOBJ (GtkSpinButton,	eMsmtPSDFreqWidth) ||
-	     !AGH_GBGETOBJ (GtkHBox,		cMsmtFreqRange) )
+     // ------------- eMsmtProfile*
+	if ( !AGH_GBGETOBJ (GtkToggleButton,	eMsmtProfileAutoscale) ||
+	     !AGH_GBGETOBJ (GtkListStore,	mMsmtProfileType) ||
+	     !AGH_GBGETOBJ (GtkComboBox,	eMsmtProfileType) ||
+	     !AGH_GBGETOBJ (GtkBox,		cMsmtProfileParams1) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eMsmtOpFreqFrom)  ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eMsmtOpFreqWidth) ||
+	     !AGH_GBGETOBJ (GtkAdjustment,	jMsmtOpFreqFrom)  ||
+	     !AGH_GBGETOBJ (GtkAdjustment,	jMsmtOpFreqWidth) ||
+	     !AGH_GBGETOBJ (GtkBox,		cMsmtMainToolbar) ||
+	     !AGH_GBGETOBJ (GtkBox,		cMsmtProfileParams2) ||
+	     !AGH_GBGETOBJ (GtkBox,		cMsmtProfileParamsContainer) )
 		return -1;
-	eMsmtPSDFreqFrom_value_changed_cb_handler_id =
-		g_signal_connect_after( eMsmtPSDFreqFrom, "value-changed",
-					(GCallback)eMsmtPSDFreqFrom_value_changed_cb,
-					this);
-	eMsmtPSDFreqWidth_value_changed_cb_handler_id =
-		g_signal_connect_after( eMsmtPSDFreqWidth, "value-changed",
-					(GCallback)eMsmtPSDFreqWidth_value_changed_cb,
-					this);
+
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start( (GtkCellLayout*)eMsmtProfileType, renderer, FALSE);
+	gtk_cell_layout_set_attributes( (GtkCellLayout*)eMsmtProfileType, renderer,
+					"text", 0,
+					NULL);
+	g_signal_connect( eMsmtProfileType, "changed",
+			  (GCallback)eMsmtProfileType_changed_cb,
+			  this);
+
+	g_signal_connect( eMsmtProfileAutoscale, "toggled",
+			  (GCallback)eMsmtProfileAutoscale_toggled_cb,
+			  this);
+
+	g_signal_connect_after( eMsmtOpFreqFrom, "value-changed",
+				(GCallback)eMsmtOpFreqFrom_value_changed_cb,
+				this);
+	g_signal_connect_after( eMsmtOpFreqWidth, "value-changed",
+				(GCallback)eMsmtOpFreqWidth_value_changed_cb,
+				this);
 
       // ------------ menus
 	if ( !(AGH_GBGETOBJ (GtkMenu,		iiSubjectTimeline)) ||
@@ -323,15 +346,16 @@ aghui::SExpDesignUI::construct_widgets()
 			  this);
 
       // ------------- lSimulations{Session,Channel}
-	if ( !AGH_GBGETOBJ (GtkLabel, lSimulationsSession) ||
-	     !AGH_GBGETOBJ (GtkLabel, lSimulationsChannel) )
+	if ( !AGH_GBGETOBJ (GtkLabel, lSimulationsProfile) ||
+	     !AGH_GBGETOBJ (GtkLabel, lSimulationsChannel) ||
+	     !AGH_GBGETOBJ (GtkLabel, lSimulationsSession) )
 		return -1;
 
     // ======= statusbar
 	if ( !AGH_GBGETOBJ (GtkStatusbar,	sbMainStatusBar) )
 		return -1;
 
-	sbContextIdGeneral = gtk_statusbar_get_context_id( sbMainStatusBar, "General context");
+	sbMainContextIdGeneral = gtk_statusbar_get_context_id( sbMainStatusBar, "General context");
 
 	if ( !(AGH_GBGETOBJ (GtkDialog,		wScanLog)) ||
 	     !(AGH_GBGETOBJ (GtkTextView,	tScanLog)) )
@@ -367,41 +391,43 @@ aghui::SExpDesignUI::construct_widgets()
 	gtk_cell_layout_set_attributes( (GtkCellLayout*)eFFTParamsWindowType, renderer,
 					"text", 0,
 					NULL);
-
       // ------------- fArtifacts
-	if ( !AGH_GBGETOBJ (GtkComboBox,	eArtifWindowType) )
+	if ( !AGH_GBGETOBJ (GtkComboBox,	eArtifDampenWindowType) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eArtifDampenFactor) )
 		return -1;
 
-	// gtk_combo_box_set_model( eArtifWindowType,
-	// 			 (GtkTreeModel*)mAfDampingWindowType);
 	renderer = gtk_cell_renderer_text_new();
-	gtk_cell_layout_pack_start( (GtkCellLayout*)eArtifWindowType, renderer, FALSE);
-	gtk_cell_layout_set_attributes( (GtkCellLayout*)eArtifWindowType, renderer,
+	gtk_cell_layout_pack_start( (GtkCellLayout*)eArtifDampenWindowType, renderer, FALSE);
+	gtk_cell_layout_set_attributes( (GtkCellLayout*)eArtifDampenWindowType, renderer,
 					"text", 0,
 					NULL);
+      // ------------- fMicrocontinuity
+	if ( !AGH_GBGETOBJ (GtkSpinButton,	eMCParamBandWidth) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eMCParamIIRBackpolate) ||
+	     !AGH_GBGETOBJ (GtkSpinButton,	eMCParamMCGain) )
+		return -1;
 
       // ------- custom score codes
-	if ( !(eScoreCode[(size_t)sigfile::SPage::TScore::none]		= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeUnscored")) ||
-	     !(eScoreCode[(size_t)sigfile::SPage::TScore::nrem1]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM1")) ||
-	     !(eScoreCode[(size_t)sigfile::SPage::TScore::nrem2]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM2")) ||
-	     !(eScoreCode[(size_t)sigfile::SPage::TScore::nrem3]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM3")) ||
-	     !(eScoreCode[(size_t)sigfile::SPage::TScore::nrem4]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM4")) ||
-	     !(eScoreCode[(size_t)sigfile::SPage::TScore::rem]		= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeREM")) ||
-	     !(eScoreCode[(size_t)sigfile::SPage::TScore::wake]		= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeWake")) ||
-	     !(eScoreCode[(size_t)sigfile::SPage::TScore::mvt]		= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeMVT")) )
+	if ( !(eScoreCode[sigfile::SPage::TScore::none]		= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeUnscored")) ||
+	     !(eScoreCode[sigfile::SPage::TScore::nrem1]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM1")) ||
+	     !(eScoreCode[sigfile::SPage::TScore::nrem2]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM2")) ||
+	     !(eScoreCode[sigfile::SPage::TScore::nrem3]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM3")) ||
+	     !(eScoreCode[sigfile::SPage::TScore::nrem4]	= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeNREM4")) ||
+	     !(eScoreCode[sigfile::SPage::TScore::rem]		= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeREM")) ||
+	     !(eScoreCode[sigfile::SPage::TScore::wake]		= (GtkEntry*)gtk_builder_get_object( __builder, "eScoreCodeWake")))
 		return -1;
 
       // --------- Bands
-	if ( !(eBand[(size_t)sigfile::TBand::delta][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandDeltaFrom")) ||
-	     !(eBand[(size_t)sigfile::TBand::delta][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandDeltaUpto")) ||
-	     !(eBand[(size_t)sigfile::TBand::theta][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandThetaFrom")) ||
-	     !(eBand[(size_t)sigfile::TBand::theta][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandThetaUpto")) ||
-	     !(eBand[(size_t)sigfile::TBand::alpha][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandAlphaFrom")) ||
-	     !(eBand[(size_t)sigfile::TBand::alpha][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandAlphaUpto")) ||
-	     !(eBand[(size_t)sigfile::TBand::beta ][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandBetaFrom" )) ||
-	     !(eBand[(size_t)sigfile::TBand::beta ][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandBetaUpto" )) ||
-	     !(eBand[(size_t)sigfile::TBand::gamma][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandGammaFrom")) ||
-	     !(eBand[(size_t)sigfile::TBand::gamma][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandGammaUpto")) )
+	if ( !(eBand[sigfile::TBand::delta][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandDeltaFrom")) ||
+	     !(eBand[sigfile::TBand::delta][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandDeltaUpto")) ||
+	     !(eBand[sigfile::TBand::theta][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandThetaFrom")) ||
+	     !(eBand[sigfile::TBand::theta][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandThetaUpto")) ||
+	     !(eBand[sigfile::TBand::alpha][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandAlphaFrom")) ||
+	     !(eBand[sigfile::TBand::alpha][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandAlphaUpto")) ||
+	     !(eBand[sigfile::TBand::beta ][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandBetaFrom" )) ||
+	     !(eBand[sigfile::TBand::beta ][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandBetaUpto" )) ||
+	     !(eBand[sigfile::TBand::gamma][0]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandGammaFrom")) ||
+	     !(eBand[sigfile::TBand::gamma][1]   = (GtkSpinButton*)gtk_builder_get_object( __builder, "eBandGammaUpto")) )
 		return -1;
 
       // --------- Misc
@@ -434,7 +460,6 @@ aghui::SExpDesignUI::construct_widgets()
 	     !AGH_GBGETOBJ (GtkLabel,		lCtlParamDBAmendment2) ||
 	     !AGH_GBGETOBJ (GtkLabel,		lCtlParamAZAmendment1) ||
 	     !AGH_GBGETOBJ (GtkLabel,		lCtlParamAZAmendment2) ||
-	     !AGH_GBGETOBJ (GtkRadioButton,	eCtlParamScoreMVTAsWake) ||
 	     !AGH_GBGETOBJ (GtkRadioButton,	eCtlParamScoreUnscoredAsWake) ||
 	     !AGH_GBGETOBJ (GtkSpinButton,	eCtlParamNSWAPpBeforeSimStart) ||
 	     !AGH_GBGETOBJ (GtkSpinButton,	eCtlParamReqScoredPercent) )
@@ -455,50 +480,50 @@ aghui::SExpDesignUI::construct_widgets()
 
       // ------------- eTunable_*
 	using namespace agh;
-	if ( !(eTunable[(size_t)TTunable::rs][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs")) ||
-	     !(eTunable[(size_t)TTunable::rs][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs_min")) ||
-	     !(eTunable[(size_t)TTunable::rs][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs_max")) ||
-	     !(eTunable[(size_t)TTunable::rs][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs_step")) ||
+	if ( !(eTunable[TTunable::rs][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs")) ||
+	     !(eTunable[TTunable::rs][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs_min")) ||
+	     !(eTunable[TTunable::rs][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs_max")) ||
+	     !(eTunable[TTunable::rs][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rs_step")) ||
 
-	     !(eTunable[(size_t)TTunable::rc][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc")) ||
-	     !(eTunable[(size_t)TTunable::rc][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc_min")) ||
-	     !(eTunable[(size_t)TTunable::rc][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc_max")) ||
-	     !(eTunable[(size_t)TTunable::rc][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc_step")) ||
+	     !(eTunable[TTunable::rc][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc")) ||
+	     !(eTunable[TTunable::rc][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc_min")) ||
+	     !(eTunable[TTunable::rc][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc_max")) ||
+	     !(eTunable[TTunable::rc][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_rc_step")) ||
 
-	     !(eTunable[(size_t)TTunable::fcR][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR")) ||
-	     !(eTunable[(size_t)TTunable::fcR][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR_min")) ||
-	     !(eTunable[(size_t)TTunable::fcR][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR_max")) ||
-	     !(eTunable[(size_t)TTunable::fcR][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR_step")) ||
+	     !(eTunable[TTunable::fcR][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR")) ||
+	     !(eTunable[TTunable::fcR][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR_min")) ||
+	     !(eTunable[TTunable::fcR][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR_max")) ||
+	     !(eTunable[TTunable::fcR][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcR_step")) ||
 
-	     !(eTunable[(size_t)TTunable::fcW][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW")) ||
-	     !(eTunable[(size_t)TTunable::fcW][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW_min")) ||
-	     !(eTunable[(size_t)TTunable::fcW][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW_max")) ||
-	     !(eTunable[(size_t)TTunable::fcW][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW_step")) ||
+	     !(eTunable[TTunable::fcW][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW")) ||
+	     !(eTunable[TTunable::fcW][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW_min")) ||
+	     !(eTunable[TTunable::fcW][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW_max")) ||
+	     !(eTunable[TTunable::fcW][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_fcW_step")) ||
 
-	     !(eTunable[(size_t)TTunable::S0][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0")) ||
-	     !(eTunable[(size_t)TTunable::S0][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0_min")) ||
-	     !(eTunable[(size_t)TTunable::S0][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0_max")) ||
-	     !(eTunable[(size_t)TTunable::S0][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0_step")) ||
+	     !(eTunable[TTunable::S0][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0")) ||
+	     !(eTunable[TTunable::S0][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0_min")) ||
+	     !(eTunable[TTunable::S0][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0_max")) ||
+	     !(eTunable[TTunable::S0][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_S0_step")) ||
 
-	     !(eTunable[(size_t)TTunable::SU][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU")) ||
-	     !(eTunable[(size_t)TTunable::SU][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU_min")) ||
-	     !(eTunable[(size_t)TTunable::SU][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU_max")) ||
-	     !(eTunable[(size_t)TTunable::SU][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU_step")) ||
+	     !(eTunable[TTunable::SU][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU")) ||
+	     !(eTunable[TTunable::SU][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU_min")) ||
+	     !(eTunable[TTunable::SU][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU_max")) ||
+	     !(eTunable[TTunable::SU][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_SU_step")) ||
 
-	     !(eTunable[(size_t)TTunable::ta][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta")) ||
-	     !(eTunable[(size_t)TTunable::ta][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta_min")) ||
-	     !(eTunable[(size_t)TTunable::ta][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta_max")) ||
-	     !(eTunable[(size_t)TTunable::ta][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta_step")) ||
+	     !(eTunable[TTunable::ta][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta")) ||
+	     !(eTunable[TTunable::ta][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta_min")) ||
+	     !(eTunable[TTunable::ta][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta_max")) ||
+	     !(eTunable[TTunable::ta][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_ta_step")) ||
 
-	     !(eTunable[(size_t)TTunable::tp][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp")) ||
-	     !(eTunable[(size_t)TTunable::tp][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp_min")) ||
-	     !(eTunable[(size_t)TTunable::tp][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp_max")) ||
-	     !(eTunable[(size_t)TTunable::tp][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp_step")) ||
+	     !(eTunable[TTunable::tp][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp")) ||
+	     !(eTunable[TTunable::tp][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp_min")) ||
+	     !(eTunable[TTunable::tp][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp_max")) ||
+	     !(eTunable[TTunable::tp][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_tp_step")) ||
 
-	     !(eTunable[(size_t)TTunable::gc][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc")) ||
-	     !(eTunable[(size_t)TTunable::gc][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc_min")) ||
-	     !(eTunable[(size_t)TTunable::gc][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc_max")) ||
-	     !(eTunable[(size_t)TTunable::gc][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc_step")) )
+	     !(eTunable[TTunable::gc][(size_t)TTIdx::val]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc")) ||
+	     !(eTunable[TTunable::gc][(size_t)TTIdx::min]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc_min")) ||
+	     !(eTunable[TTunable::gc][(size_t)TTIdx::max]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc_max")) ||
+	     !(eTunable[TTunable::gc][(size_t)TTIdx::step]	= (GtkSpinButton*)gtk_builder_get_object( __builder, "eTunable_gc_step")) )
 		return -1;
 
 	for ( size_t t = 0; t < (size_t)TTunable::_basic_tunables; ++t )
@@ -513,41 +538,41 @@ aghui::SExpDesignUI::construct_widgets()
 			  this);
 
       // ------ colours
-	if ( !(CwB[TColour::night	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNight")) ||
-	     !(CwB[TColour::day		].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourDay")) ||
-	     !(CwB[TColour::power_mt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourPowerMT")) ||
-	     !(CwB[TColour::ticks_mt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourTicksMT")) ||
-	     !(CwB[TColour::labels_mt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourLabelsMT")) ||
+	if ( !(CwB[TColour::night	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNight")) ||
+	     !(CwB[TColour::day		  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourDay")) ||
+	     !(CwB[TColour::power_mt	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourPowerMT")) ||
+	     !(CwB[TColour::ticks_mt	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourTicksMT")) ||
+	     !(CwB[TColour::labels_mt	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourLabelsMT")) ||
 
-	     !(CwB[TColour::swa	     	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourSWA")) ||
-	     !(CwB[TColour::swa_sim  	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourSWASim")) ||
-	     !(CwB[TColour::process_s	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourProcessS")) ||
-	     !(CwB[TColour::paper_mr	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourPaperMR")) ||
-	     !(CwB[TColour::ticks_mr	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourTicksMR")) ||
-	     !(CwB[TColour::labels_mr	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourLabelsMR")) ||
+	     !(CwB[TColour::swa	     	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourSWA")) ||
+	     !(CwB[TColour::swa_sim  	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourSWASim")) ||
+	     !(CwB[TColour::process_s	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourProcessS")) ||
+	     !(CwB[TColour::paper_mr	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourPaperMR")) ||
+	     !(CwB[TColour::ticks_mr	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourTicksMR")) ||
+	     !(CwB[TColour::labels_mr	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourLabelsMR")) ||
 
-	     !(CwB[TColour::score_none	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNONE")) ||
-	     !(CwB[TColour::score_nrem1	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM1")) ||
-	     !(CwB[TColour::score_nrem2	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM2")) ||
-	     !(CwB[TColour::score_nrem3	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM3")) ||
-	     !(CwB[TColour::score_nrem4	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM4")) ||
-	     !(CwB[TColour::score_rem	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourREM")) ||
-	     !(CwB[TColour::score_wake	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourWake")) ||
-	     !(CwB[TColour::score_mvt	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourWake")) ||
-	     !(CwB[TColour::power_sf	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourPowerSF")) ||
-	     !(CwB[TColour::emg		].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourEMG")) ||
-	     !(CwB[TColour::hypnogram	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourHypnogram")) ||
-	     !(CwB[TColour::artifact	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourArtifacts")) ||
-	     !(CwB[TColour::annotations	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourAnnotations")) ||
-	     !(CwB[TColour::selection	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourSelection")) ||
-	     !(CwB[TColour::ticks_sf	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourTicksSF")) ||
-	     !(CwB[TColour::labels_sf	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourLabelsSF")) ||
-	     !(CwB[TColour::cursor	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourCursor")) ||
-	     !(CwB[TColour::band_delta	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandDelta")) ||
-	     !(CwB[TColour::band_theta	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandTheta")) ||
-	     !(CwB[TColour::band_alpha	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandAlpha")) ||
-	     !(CwB[TColour::band_beta	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandBeta")) ||
-	     !(CwB[TColour::band_gamma	].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandGamma")) )
+	     !(CwB[TColour::score_none	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNONE")) ||
+	     !(CwB[TColour::score_nrem1	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM1")) ||
+	     !(CwB[TColour::score_nrem2	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM2")) ||
+	     !(CwB[TColour::score_nrem3	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM3")) ||
+	     !(CwB[TColour::score_nrem4	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourNREM4")) ||
+	     !(CwB[TColour::score_rem	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourREM")) ||
+	     !(CwB[TColour::score_wake	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourWake")) ||
+	     !(CwB[TColour::profile_psd_sf].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourProfilePsdSF")) ||
+	     !(CwB[TColour::profile_mc_sf ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourProfileMcSF")) ||
+	     !(CwB[TColour::emg		  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourEMG")) ||
+	     !(CwB[TColour::hypnogram	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourHypnogram")) ||
+	     !(CwB[TColour::artifact	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourArtifacts")) ||
+	     !(CwB[TColour::annotations	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourAnnotations")) ||
+	     !(CwB[TColour::selection	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourSelection")) ||
+	     !(CwB[TColour::ticks_sf	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourTicksSF")) ||
+	     !(CwB[TColour::labels_sf	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourLabelsSF")) ||
+	     !(CwB[TColour::cursor	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourCursor")) ||
+	     !(CwB[TColour::band_delta	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandDelta")) ||
+	     !(CwB[TColour::band_theta	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandTheta")) ||
+	     !(CwB[TColour::band_alpha	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandAlpha")) ||
+	     !(CwB[TColour::band_beta	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandBeta")) ||
+	     !(CwB[TColour::band_gamma	  ].btn = (GtkColorButton*)gtk_builder_get_object( __builder, "bColourBandGamma")) )
 		return -1;
 
       // scrub colours
@@ -561,24 +586,9 @@ aghui::SExpDesignUI::construct_widgets()
 
       // ========= child widgets
       // ----- wAbout
-	if ( !(AGH_GBGETOBJ (GtkDialog,		wAbout)) ||
-	     !(AGH_GBGETOBJ (GtkTextView,	tREADME)) )
+	if ( !(AGH_GBGETOBJ (GtkDialog,		wAbout)) )
 		return -1;
 
-	{
-		gtk_widget_override_font( (GtkWidget*)tREADME, font_desc);
-		char *contents;
-		snprintf_buf( "%s/doc/%s/README", PACKAGE_DATADIR, PACKAGE);
-		GFile *file = g_file_new_for_path( __buf__);
-		gtk_text_buffer_set_text(
-			gtk_text_view_get_buffer( tREADME),
-			g_file_load_contents( file, NULL, &contents, NULL, NULL, NULL)
-			? contents
-			: "(The contents of " PACKAGE_DATADIR "/README was supposed to be here;\n"
-			"this file was not found in that location, too bad.)", -1);
-		g_object_unref( file);
-	}
-
 
       // ------- wEDFFileDetails
 	if ( !AGH_GBGETOBJ (GtkDialog,		wEDFFileDetails) ||
@@ -588,16 +598,14 @@ aghui::SExpDesignUI::construct_widgets()
 	// used by two GtkTextView's, lEDFFileDetailsReport and lEdfImportFileInfo
 	if ( !AGH_GBGETOBJ (GtkTextBuffer,	tEDFFileDetailsReport) )
 		return -1;
-	// g_object_get( tEDFFileDetailsReport, "style", &sty, NULL);
-	// sty->font_desc = monofont;
 
+	gtk_widget_override_font( (GtkWidget*)lEDFFileDetailsReport, font_desc);
 	g_object_set( lEDFFileDetailsReport,
 		      "tabs", pango_tab_array_new_with_positions(
 			      2, TRUE,
 			      PANGO_TAB_LEFT, 180,
 			      PANGO_TAB_LEFT, 190),
 		      NULL);
-	gtk_widget_override_font( (GtkWidget*)lEDFFileDetailsReport, font_desc);
 
       // ------- wEdfImport
 	if ( !AGH_GBGETOBJ (GtkDialog,		wEdfImport) ||
@@ -616,6 +624,7 @@ aghui::SExpDesignUI::construct_widgets()
 	     !AGH_GBGETOBJ (GtkButton,		bEdfImportEdfhed) )
 		return -1;
 
+	gtk_widget_override_font( (GtkWidget*)lEdfImportFileInfo, font_desc);
 	g_object_set( lEdfImportFileInfo,
 		      "tabs", pango_tab_array_new_with_positions( 2, TRUE,
 								  PANGO_TAB_LEFT, 130,
@@ -662,7 +671,8 @@ aghui::SExpDesignUI::construct_widgets()
 	     !(AGH_GBGETOBJ (GtkButton,		bExpDesignChooserSelect)) ||
 	     !(AGH_GBGETOBJ (GtkButton,		bExpDesignChooserCreateNew)) ||
 	     !(AGH_GBGETOBJ (GtkButton,		bExpDesignChooserRemove)) ||
-	     !(AGH_GBGETOBJ (GtkButton,		bExpDesignChooserQuit)) )
+	     !(AGH_GBGETOBJ (GtkButton,		bExpDesignChooserQuit)) ||
+	     !(AGH_GBGETOBJ (GtkStatusbar,	sbExpDesignChooserStatusBar)) )
 		return -1;
 
 	g_signal_connect( wExpDesignChooser, "show",
@@ -675,9 +685,10 @@ aghui::SExpDesignUI::construct_widgets()
 	g_signal_connect( gtk_tree_view_get_selection( tvExpDesignChooserList), "changed",
 			  (GCallback)tvExpDesignChooserList_changed_cb,
 			  this);
-	g_signal_connect( bExpDesignChooserSelect, "clicked",
-			  (GCallback)bExpDesignChooserSelect_clicked_cb,
-			  this);
+	bExpDesignChooserSelect_clicked_cb_handler =
+		g_signal_connect( bExpDesignChooserSelect, "clicked",
+				  (GCallback)bExpDesignChooserSelect_clicked_cb,
+				  this);
 	g_signal_connect( bExpDesignChooserCreateNew, "clicked",
 			  (GCallback)bExpDesignChooserCreateNew_clicked_cb,
 			  this);
@@ -703,6 +714,8 @@ aghui::SExpDesignUI::construct_widgets()
 						     "text", 0,
 						     NULL);
 
+	sbChooserContextIdGeneral = gtk_statusbar_get_context_id( sbExpDesignChooserStatusBar, "General context");
+
 	pango_font_description_free( font_desc);
 
 	return 0;
