@@ -20,6 +20,7 @@ using namespace std;
 using namespace aghui;
 
 
+
 extern "C"
 void
 tDesign_switch_page_cb( GtkNotebook     *notebook,
@@ -34,33 +35,50 @@ tDesign_switch_page_cb( GtkNotebook     *notebook,
 	if ( page_num == 0 ) {  // switching back from settings tab
 
 	      // collect values from widgets
-		ED.ED->fft_params.page_size =
-			ED.FFTPageSizeValues[ ED.pagesize_item = gtk_combo_box_get_active( ED.eFFTParamsPageSize)];
-		ED.ED->fft_params.bin_size =
-			ED.FFTBinSizeValues[ ED.binsize_item = gtk_combo_box_get_active( ED.eFFTParamsBinSize)];
-		if ( not ED.ED->fft_params.validate() )
-			;
+		// Profile tab
+		ED.ED->af_dampen_window_type =
+			(SFFTParamSet::TWinType)gtk_combo_box_get_active( ED.eArtifDampenWindowType);
+		ED.ED->af_dampen_factor =
+			gtk_spin_button_get_value( ED.eArtifDampenFactor);
 
+		ED.ED->fft_params.pagesize =
+			ED.FFTPageSizeValues[ ED.pagesize_item = gtk_combo_box_get_active( ED.eFFTParamsPageSize)];
+		ED.ED->fft_params.binsize =
+			ED.FFTBinSizeValues[ ED.binsize_item = gtk_combo_box_get_active( ED.eFFTParamsBinSize)];
 		ED.ED->fft_params.welch_window_type =
 			(SFFTParamSet::TWinType)gtk_combo_box_get_active( ED.eFFTParamsWindowType);
-		// ED.ED->fft_params.freq_trunc =
-		// 	gtk_spin_button_get_value( ED.eFFTParamsFreqTrunc);
-		ED.ED->af_dampen_window_type =
-			(SFFTParamSet::TWinType)gtk_combo_box_get_active( ED.eArtifWindowType);
+		try { ED.ED->fft_params.check(); }
+		catch (invalid_argument ex) {
+			pop_ok_message( ED.wMainWindow, "Invalid FFT parameters; resetting to defaults.");
+			ED.ED->fft_params.reset();
+		}
 
+		ED.ED->mc_params.bandwidth		=         gtk_spin_button_get_value( ED.eMCParamBandWidth);
+		ED.ED->mc_params.iir_backpolate		=         gtk_spin_button_get_value( ED.eMCParamIIRBackpolate);
+		ED.ED->mc_params.mc_gain		=         gtk_spin_button_get_value( ED.eMCParamMCGain);
+		try {
+			ED.ED->mc_params.check( ED.ED->fft_params.pagesize);
+		} catch (invalid_argument ex) {
+			pop_ok_message( ED.wMainWindow, "Invalid MC parameters; resetting to defaults.");
+			ED.ED->mc_params.reset( ED.ED->fft_params.pagesize);
+		}
+
+		ED.__adjust_op_freq_spinbuttons();
+
+		// General tab
 		for ( gushort i = 0; i < (size_t)SPage::TScore::_total; ++i )
 			ED.ext_score_codes[i] = gtk_entry_get_text( ED.eScoreCode[i]);
 
-		ED.freq_bands[(size_t)TBand::delta][0] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::delta][0]);
-		ED.freq_bands[(size_t)TBand::delta][1] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::delta][1]);
-		ED.freq_bands[(size_t)TBand::theta][0] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::theta][0]);
-		ED.freq_bands[(size_t)TBand::theta][1] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::theta][1]);
-		ED.freq_bands[(size_t)TBand::alpha][0] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::alpha][0]);
-		ED.freq_bands[(size_t)TBand::alpha][1] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::alpha][1]);
-		ED.freq_bands[(size_t)TBand::beta ][0] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::beta ][0]);
-		ED.freq_bands[(size_t)TBand::beta ][1] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::beta ][1]);
-		ED.freq_bands[(size_t)TBand::gamma][0] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::gamma][0]);
-		ED.freq_bands[(size_t)TBand::gamma][1] = gtk_spin_button_get_value( ED.eBand[(size_t)TBand::gamma][1]);
+		ED.freq_bands[TBand::delta][0] = gtk_spin_button_get_value( ED.eBand[TBand::delta][0]);
+		ED.freq_bands[TBand::delta][1] = gtk_spin_button_get_value( ED.eBand[TBand::delta][1]);
+		ED.freq_bands[TBand::theta][0] = gtk_spin_button_get_value( ED.eBand[TBand::theta][0]);
+		ED.freq_bands[TBand::theta][1] = gtk_spin_button_get_value( ED.eBand[TBand::theta][1]);
+		ED.freq_bands[TBand::alpha][0] = gtk_spin_button_get_value( ED.eBand[TBand::alpha][0]);
+		ED.freq_bands[TBand::alpha][1] = gtk_spin_button_get_value( ED.eBand[TBand::alpha][1]);
+		ED.freq_bands[TBand::beta ][0] = gtk_spin_button_get_value( ED.eBand[TBand::beta ][0]);
+		ED.freq_bands[TBand::beta ][1] = gtk_spin_button_get_value( ED.eBand[TBand::beta ][1]);
+		ED.freq_bands[TBand::gamma][0] = gtk_spin_button_get_value( ED.eBand[TBand::gamma][0]);
+		ED.freq_bands[TBand::gamma][1] = gtk_spin_button_get_value( ED.eBand[TBand::gamma][1]);
 
 		SScoringFacility::IntersignalSpace	= gtk_spin_button_get_value( ED.eDAPageHeight);
 		SScoringFacility::HypnogramHeight	= gtk_spin_button_get_value( ED.eDAHypnogramHeight);
@@ -69,54 +87,60 @@ tDesign_switch_page_cb( GtkNotebook     *notebook,
 		ED.browse_command.assign( gtk_entry_get_text( ED.eBrowseCommand));
 
 	      // scan as necessary
-		if ( ED.pagesize_item_saved	  != ED.pagesize_item ||
-		     ED.binsize_item_saved	  != ED.binsize_item ||
-		     ED.FFTWindowType_saved	  != ED.ED->fft_params.welch_window_type ||
-		     ED.AfDampingWindowType_saved != ED.ED->af_dampen_window_type ) {
+		if ( ED.pagesize_item_saved	  		!= ED.pagesize_item ||
+		     ED.binsize_item_saved	  		!= ED.binsize_item ||
+		     ED.fft_params_welch_window_type_saved  	!= ED.ED->fft_params.welch_window_type ||
+		     ED.af_dampen_window_type_saved  		!= ED.ED->af_dampen_window_type ||
+		     ED.af_dampen_factor_saved	  		!= ED.ED->af_dampen_factor ||
+		     !(ED.ED->mc_params				== ED.mc_params_saved) ) {
 		      // rescan tree
 			ED.do_rescan_tree(); // with populate
 		}
 	} else {
-		ED.pagesize_item_saved		= ED.pagesize_item;
-		ED.binsize_item_saved		= ED.binsize_item;
-		ED.FFTWindowType_saved		= ED.ED->fft_params.welch_window_type;
-		ED.AfDampingWindowType_saved	= ED.ED->af_dampen_window_type;
-		//ED.FFTFreqTrunc_saved		= ED.ED->fft_params.freq_trunc;
+		ED.pagesize_item_saved			= ED.pagesize_item;
+		ED.binsize_item_saved			= ED.binsize_item;
+		ED.fft_params_welch_window_type_saved	= ED.ED->fft_params.welch_window_type;
+		ED.af_dampen_window_type_saved		= ED.ED->af_dampen_window_type;
+		ED.af_dampen_factor_saved		= ED.ED->af_dampen_factor;
+		ED.mc_params_saved			= ED.ED->mc_params;
 
 	      // also assign values to widgets
 		// -- maybe not? None of them are changeable by user outside settings tab
 		// -- rather do: they are loaded at init
-		// FFT parameters
+		// Profile tab
 		guint i = 0;
-		while ( SExpDesignUI::FFTPageSizeValues[i] < ED.ED->fft_params.page_size )
+		while ( SExpDesignUI::FFTPageSizeValues[i] < ED.ED->fft_params.pagesize )
 			++i;
 		gtk_combo_box_set_active( ED.eFFTParamsPageSize, ED.pagesize_item = i);
 		i = 0;
-		while ( SExpDesignUI::FFTBinSizeValues[i] < ED.ED->fft_params.bin_size )
+		while ( SExpDesignUI::FFTBinSizeValues[i] < ED.ED->fft_params.binsize )
 			++i;
 		gtk_combo_box_set_active( ED.eFFTParamsBinSize, ED.binsize_item = i);
-
 		gtk_combo_box_set_active( ED.eFFTParamsWindowType, (int)ED.ED->fft_params.welch_window_type);
-		//gtk_spin_button_set_value( ED.eFFTParamsFreqTrunc, ED.ED->fft_params.freq_trunc);
+
+		gtk_spin_button_set_value( ED.eMCParamIIRBackpolate,	ED.ED->mc_params.iir_backpolate);
+		gtk_spin_button_set_value( ED.eMCParamMCGain,		ED.ED->mc_params.mc_gain);
+		gtk_spin_button_set_value( ED.eMCParamBandWidth,	ED.ED->mc_params.bandwidth);
 
 		// artifacts
-		gtk_combo_box_set_active( ED.eArtifWindowType, (int)ED.ED->af_dampen_window_type);
+		gtk_combo_box_set_active( ED.eArtifDampenWindowType, (int)ED.ED->af_dampen_window_type);
+		gtk_spin_button_set_value( ED.eArtifDampenFactor,	ED.ED->af_dampen_factor);
 
 		// custom score codes
 		for ( gushort i = 0; i < (size_t)SPage::TScore::_total; ++i )
 			gtk_entry_set_text( ED.eScoreCode[i], ED.ext_score_codes[i].c_str());
 
 		// misc
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::delta][0], ED.freq_bands[(size_t)TBand::delta][0]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::delta][1], ED.freq_bands[(size_t)TBand::delta][1]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::theta][0], ED.freq_bands[(size_t)TBand::theta][0]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::theta][1], ED.freq_bands[(size_t)TBand::theta][1]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::alpha][0], ED.freq_bands[(size_t)TBand::alpha][0]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::alpha][1], ED.freq_bands[(size_t)TBand::alpha][1]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::beta ][0], ED.freq_bands[(size_t)TBand::beta ][0]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::beta ][1], ED.freq_bands[(size_t)TBand::beta ][1]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::gamma][0], ED.freq_bands[(size_t)TBand::gamma][0]);
-		gtk_spin_button_set_value( ED.eBand[(size_t)TBand::gamma][1], ED.freq_bands[(size_t)TBand::gamma][1]);
+		gtk_spin_button_set_value( ED.eBand[TBand::delta][0], ED.freq_bands[TBand::delta][0]);
+		gtk_spin_button_set_value( ED.eBand[TBand::delta][1], ED.freq_bands[TBand::delta][1]);
+		gtk_spin_button_set_value( ED.eBand[TBand::theta][0], ED.freq_bands[TBand::theta][0]);
+		gtk_spin_button_set_value( ED.eBand[TBand::theta][1], ED.freq_bands[TBand::theta][1]);
+		gtk_spin_button_set_value( ED.eBand[TBand::alpha][0], ED.freq_bands[TBand::alpha][0]);
+		gtk_spin_button_set_value( ED.eBand[TBand::alpha][1], ED.freq_bands[TBand::alpha][1]);
+		gtk_spin_button_set_value( ED.eBand[TBand::beta ][0], ED.freq_bands[TBand::beta ][0]);
+		gtk_spin_button_set_value( ED.eBand[TBand::beta ][1], ED.freq_bands[TBand::beta ][1]);
+		gtk_spin_button_set_value( ED.eBand[TBand::gamma][0], ED.freq_bands[TBand::gamma][0]);
+		gtk_spin_button_set_value( ED.eBand[TBand::gamma][1], ED.freq_bands[TBand::gamma][1]);
 
 		gtk_spin_button_set_value( ED.eDAPageHeight,		SScoringFacility::IntersignalSpace);
 		gtk_spin_button_set_value( ED.eDAHypnogramHeight,	SScoringFacility::HypnogramHeight);
@@ -231,8 +255,6 @@ tSimulations_switch_page_cb( GtkNotebook     *notebook,
 		gtk_spin_button_set_value( ED.eCtlParamReqScoredPercent, ED.ED->ctl_params0.req_percent_scored);
 
 	      // Unconventional scores frame
-		gtk_toggle_button_set_active( (GtkToggleButton*)ED.eCtlParamScoreMVTAsWake,
-					      ED.ED->ctl_params0.ScoreMVTAsWake);
 		gtk_toggle_button_set_active( (GtkToggleButton*)ED.eCtlParamScoreUnscoredAsWake,
 					      ED.ED->ctl_params0.ScoreUnscoredAsWake);
 
@@ -259,7 +281,6 @@ tSimulations_switch_page_cb( GtkNotebook     *notebook,
 		ED.ED->ctl_params0.req_percent_scored		= gtk_spin_button_get_value( ED.eCtlParamReqScoredPercent);
 
 	      // Unconventional scores frame
-		ED.ED->ctl_params0.ScoreMVTAsWake      = gtk_toggle_button_get_active( (GtkToggleButton*)ED.eCtlParamScoreMVTAsWake);
 		ED.ED->ctl_params0.ScoreUnscoredAsWake = gtk_toggle_button_get_active( (GtkToggleButton*)ED.eCtlParamScoreUnscoredAsWake);
 
 	      // Tunables tab
@@ -294,7 +315,7 @@ void
 bSimParamRevertTunables_clicked_cb( GtkButton *button, gpointer userdata)
 {
 	auto& ED = *(SExpDesignUI*)userdata;
-	ED.ED->tunables0.assign_defaults();
+	ED.ED->tunables0.reset();
 	__tunables_to_widgets( ED);
 }
 
