@@ -22,34 +22,6 @@ using namespace aghui;
 extern "C" {
 
 
-// void
-// bSimulationsRun_clicked_cb( GtkToolButton *toolbutton,
-// 			    gpointer userdata)
-// {
-// 	auto& ED = *(SExpDesignUI*)userdata;
-
-// 	GtkTreeSelection *selection = gtk_tree_view_get_selection( ED.tvSimulations);
-// 	GtkTreeModel *model;
-// 	GList *paths = gtk_tree_selection_get_selected_rows( selection, &model);
-// 	if ( !paths )
-// 		return;
-// 	GtkTreePath *path = (GtkTreePath*) g_list_nth_data( paths, 0);
-
-// 	if ( gtk_tree_path_get_depth( path) > 3 ) {
-// 		agh::CSimulation *modref;
-// 		GtkTreeIter iter;
-// 		gtk_tree_model_get_iter( model, &iter, path);
-// 		gtk_tree_model_get( model, &iter,
-// 				    ED.msimulations_modref_col, &modref,
-// 				    -1);
-// 		if ( modref )
-// 			new SModelrunFacility( *modref, ED);
-// 	}
-
-// 	gtk_tree_path_free( path);
-// 	g_list_free( paths);
-// }
-
 
 void
 tvSimulations_row_activated_cb( GtkTreeView* tree_view,
@@ -58,7 +30,7 @@ tvSimulations_row_activated_cb( GtkTreeView* tree_view,
 				gpointer userdata)
 {
 	auto& ED = *(SExpDesignUI*)userdata;
-	agh::CSimulation *modref;
+	agh::CModelRun *modref;
 	GtkTreeIter iter;
 	gtk_tree_model_get_iter( (GtkTreeModel*)ED.mSimulations, &iter, path);
 	gtk_tree_model_get( (GtkTreeModel*)ED.mSimulations, &iter,
@@ -78,8 +50,23 @@ iSimulationsRunBatch_activate_cb( GtkMenuItem*, gpointer userdata)
 	gtk_entry_set_text( ED.eBatchSetupSubjects, string_join( ED.ED->enumerate_subjects(), "; ").c_str());
 	gtk_entry_set_text( ED.eBatchSetupSessions, string_join( ED.ED->enumerate_sessions(), "; ").c_str());
 	gtk_entry_set_text( ED.eBatchSetupChannels, string_join( ED.ED->enumerate_eeg_channels(), "; ").c_str());
+
+      // prevent inapplicable inputs when type == mc
+	if ( ED.display_profile_type == sigfile::TMetricType::Mc ) {
+		gtk_spin_button_set_value( ED.eBatchSetupRangeWidth, ED.ED->mc_params.bandwidth);
+		gtk_spin_button_set_value( ED.eBatchSetupRangeInc, ED.ED->mc_params.bandwidth);
+		gtk_widget_set_sensitive( (GtkWidget*)ED.eBatchSetupRangeWidth, FALSE);
+		gtk_widget_set_sensitive( (GtkWidget*)ED.eBatchSetupRangeInc, FALSE);
+	} else {
+		auto bw = ED.operating_range_upto - ED.operating_range_from;
+		gtk_spin_button_set_value( ED.eBatchSetupRangeWidth, bw);
+		gtk_spin_button_set_value( ED.eBatchSetupRangeInc, bw);
+		gtk_widget_set_sensitive( (GtkWidget*)ED.eBatchSetupRangeWidth, TRUE);
+		gtk_widget_set_sensitive( (GtkWidget*)ED.eBatchSetupRangeInc, TRUE);
+	}
+
 	if ( gtk_dialog_run( ED.wBatchSetup) == GTK_RESPONSE_OK ) {
-		ED.ED->remove_all_modruns();
+		ED.ED->remove_untried_modruns();
 		ED.populate_2();
 
 		list<string>
@@ -101,18 +88,19 @@ iSimulationsRunBatch_activate_cb( GtkMenuItem*, gpointer userdata)
 						range_upto = freq_from + freq_width;
 					for ( size_t step = 0; step < freq_steps;
 					      ++step, range_from += freq_width, range_upto += freq_width ) {
-						agh::CSimulation *sim;
+						agh::CModelRun *sim;
 						int retval =
 							ED.ED->setup_modrun( J.c_str(), D.c_str(), H.c_str(),
+									     ED.display_profile_type,
 									     range_from, range_upto,
 									     sim);
 						if ( retval ) {
 							; // didn't work
 						} else {
-							snprintf_buf( "Running simulation in %s (%g-%g) for %s (%s) ...",
+							snprintf_buf( "Running simulation in channel %s (%g-%g Hz) for %s (session %s) ...",
 								      H.c_str(), range_from, range_upto,
 								      J.c_str(), D.c_str());
-							ED.buf_on_status_bar();
+							ED.buf_on_main_status_bar();
 							sim -> watch_simplex_move( nullptr);
 						}
 					}
@@ -120,7 +108,7 @@ iSimulationsRunBatch_activate_cb( GtkMenuItem*, gpointer userdata)
 					gtk_flush();
 				}
 		snprintf_buf( "Done");
-		ED.buf_on_status_bar();
+		ED.buf_on_main_status_bar();
 		set_cursor_busy( false, (GtkWidget*)ED.wMainWindow);
 		gtk_widget_set_sensitive( (GtkWidget*)ED.wMainWindow, TRUE);
 	}
