@@ -13,12 +13,14 @@
 
 #include <cstring>
 #include <ctime>
+#include <functional>
 
 #include <cairo.h>
 #include <cairo-svg.h>
 //#include <vte/vte.h>
 
-#include "../core/boost-config-validate.hh"
+#include "../common/config-validate.hh"
+#include "../libsigfile/page-metrics-base.hh"
 #include "misc.hh"
 #include "expdesign.hh"
 #include "scoring-facility.hh"
@@ -30,27 +32,44 @@ using namespace aghui;
 
 
 
-aghui::SExpDesignUI::SSubjectPresentation::SSubjectPresentation( agh::CSubject& _j, SGroupPresentation& parent)
+aghui::SExpDesignUI::SSubjectPresentation::
+SSubjectPresentation( agh::CSubject& _j,
+		      SGroupPresentation& parent)
       : csubject (_j),
+	using_episode (nullptr),
 	is_focused (false),
 	_p (parent),
 	da (NULL)
 {
-	try {
-		cscourse = new agh::CSCourse (csubject, *_p._p._AghDi, *_p._p._AghTi,
-					      _p._p.operating_range_from, _p._p.operating_range_upto,
-					      0., 0, false, false);
-		tl_start = csubject.measurements[*_p._p._AghDi].episodes.front().start_rel;
-	} catch (...) {  // can be invalid_argument (no recording in such session/channel) or some TSimPrepError
-		cscourse = NULL;
-		fprintf( stderr, "SSubjectPresentation::SSubjectPresentation(): subject %s has no recordings in session %s channel %s\n",
-			 csubject.name(), _p._p.AghD(), _p._p.AghT());
-	}
-	using_episode = sepisodesequence().end();
+	cscourse = nullptr;
+	create_cscourse();
 }
 
 
-aghui::SExpDesignUI::SSubjectPresentation::~SSubjectPresentation()
+void
+aghui::SExpDesignUI::SSubjectPresentation::
+create_cscourse()
+{
+	if ( cscourse )
+		delete cscourse;
+	try {
+		cscourse =
+			new agh::CSCourse (
+				csubject, *_p._p._AghDi, *_p._p._AghTi,
+				agh::SSCourseParamSet {
+					_p._p.display_profile_type,
+					_p._p.operating_range_from, _p._p.operating_range_upto,
+					0., 0, false, false});
+		tl_start = csubject.measurements[*_p._p._AghDi].episodes.front().start_rel;
+	} catch (...) {  // can be invalid_argument (no recording in such session/channel) or some TSimPrepError
+		cscourse = nullptr;
+		fprintf( stderr, "SSubjectPresentation::SSubjectPresentation(): subject %s has no recordings in session %s channel %s\n",
+			 csubject.name(), _p._p.AghD(), _p._p.AghT());
+	}
+}
+
+aghui::SExpDesignUI::SSubjectPresentation::
+~SSubjectPresentation()
 {
 	if ( cscourse )
 		delete cscourse;
@@ -61,7 +80,8 @@ aghui::SExpDesignUI::SSubjectPresentation::~SSubjectPresentation()
 
 
 aghui::SExpDesignUI::SSubjectPresentation*
-SExpDesignUI::subject_presentation_by_csubject( const agh::CSubject& j)
+SExpDesignUI::
+subject_presentation_by_csubject( const agh::CSubject& j)
 {
 	for ( auto& G : groups )
 		for ( auto& J : G )
@@ -84,57 +104,58 @@ const array<double, 3>
 
 
 
-aghui::SExpDesignUI::SExpDesignUI( const string& dir)
+aghui::SExpDesignUI::
+SExpDesignUI( const string& dir)
       : // let ED and cgroups be initialized after the UI gets constructed
 	// so we could entertain the user with progress_indicator
 	// ED (NULL),
 	// groups (*this),  // incomplete
-	using_subject (NULL),
+	using_subject (nullptr),
 	finalize_ui (false),
+	suppress_redraw (false),
+	display_profile_type (sigfile::TMetricType::Psd),
 	operating_range_from (2.),
 	operating_range_upto (3.),
 	pagesize_item (2),
 	binsize_item (1),
-	ext_score_codes {
-		sigfile::CHypnogram::TCustomScoreCodes {{" -0", "1", "2", "3", "4", "6Rr8", "Ww5", "mM"}}
-	},
-	freq_bands ({
+	ext_score_codes (
+		{{{" -0"}, {"1"}, {"2"}, {"3"}, {"4"}, {"6Rr8"}, {"Ww5"}}}
+	),
+	freq_bands {
 		{  1.5,  4.0 },
 		{  4.0,  8.0 },
 		{  8.0, 12.0 },
 		{ 15.0, 30.0 },
 		{ 30.0, 40.0 },
-	}),
-	ppuv2 (1e-5),
-	timeline_height (70),
-	timeline_pph (20),
-	runbatch_include_all_channels (false),
-	runbatch_include_all_sessions (false),
-	runbatch_iterate_ranges (false),
+	},
+	profile_scale_psd (0.),
+	profile_scale_mc (0.),
+	autoscale (false),
+	timeline_height (80),
+	timeline_pph (30),
 	config_keys_s ({
-		SValidator<string>("WindowGeometry.Main",		&_geometry_placeholder),
-		SValidator<string>("Common.CurrentSession",		&_aghdd_placeholder),
-		SValidator<string>("Common.CurrentChannel",		&_aghtt_placeholder),
-		SValidator<string>("Measurements.BrowseCommand",	&browse_command),
+		confval::SValidator<string>("WindowGeometry.Main",		&_geometry_placeholder),
+		confval::SValidator<string>("Common.CurrentSession",		&_aghdd_placeholder),
+		confval::SValidator<string>("Common.CurrentChannel",		&_aghtt_placeholder),
+		confval::SValidator<string>("Measurements.BrowseCommand",	&browse_command),
 	}),
-	config_keys_b ({
-		SValidator<bool>("BatchRun.IncludeAllChannels",		&runbatch_include_all_channels),
-		SValidator<bool>("BatchRun.IncludeAllSessions",		&runbatch_include_all_sessions),
-		SValidator<bool>("BatchRun.IterateRanges",		&runbatch_iterate_ranges),
-	}),
-	config_keys_z ({
-		SValidator<size_t>("Measurements.TimelineHeight",	&timeline_height,			SValidator<size_t>::SVFRange (10, 600)),
-		SValidator<size_t>("Measurements.TimelinePPH",		&timeline_pph,				SValidator<size_t>::SVFRange (10, 600)),
-		SValidator<size_t>("ScoringFacility.IntersignalSpace",	&SScoringFacility::IntersignalSpace,	SValidator<size_t>::SVFRange (10, 800)),
-		SValidator<size_t>("ScoringFacility.HypnogramHeight",	&SScoringFacility::HypnogramHeight,	SValidator<size_t>::SVFRange (10, 300)),
-		SValidator<size_t>("ModelRun.SWASmoothOver",		&SModelrunFacility::swa_smoothover,	SValidator<size_t>::SVFRange (0, 4)),
+	config_keys_d ({
+		confval::SValidator<int>("Measurements.DisplayProfileMode",	(int*)&display_profile_type,			confval::SValidator<int>::SVFRangeIn (0, 1)),
+		confval::SValidator<int>("Measurements.TimelineHeight",		(int*)&timeline_height,				confval::SValidator<int>::SVFRangeIn (10, 600)),
+		confval::SValidator<int>("Measurements.TimelinePPH",		(int*)&timeline_pph,				confval::SValidator<int>::SVFRangeIn (10, 600)),
+		confval::SValidator<int>("ScoringFacility.IntersignalSpace",	(int*)&SScoringFacility::IntersignalSpace,	confval::SValidator<int>::SVFRangeIn (10, 800)),
+		confval::SValidator<int>("ScoringFacility.HypnogramHeight",	(int*)&SScoringFacility::HypnogramHeight,	confval::SValidator<int>::SVFRangeIn (10, 300)),
+		confval::SValidator<int>("ModelRun.SWASmoothOver",		(int*)&SModelrunFacility::swa_smoothover,	confval::SValidator<int>::SVFRangeIn (1, 5)),
 	}),
 	config_keys_g ({
-		SValidator<float>("Measurements.TimelinePPuV2",		&ppuv2,					SValidator<float>::SVFRange (1e-10, 1e10)),
-		SValidator<float>("Common.OperatingRangeFrom",		&operating_range_from,			SValidator<float>::SVFRange (0., 20.)),
-		SValidator<float>("Common.OperatingRangeUpto",		&operating_range_upto,			SValidator<float>::SVFRange (0., 20.)),
+		confval::SValidator<float>("Measurements.ProfileScalePSD",	&profile_scale_psd,			confval::SValidator<float>::SVFRangeIn (0., 1e10)), // can be 0, will trigger autoscale
+		confval::SValidator<float>("Measurements.ProfileScaleMC",	&profile_scale_mc,			confval::SValidator<float>::SVFRangeIn (0., 1e10)),
+		confval::SValidator<float>("Common.OperatingRangeFrom",		&operating_range_from,			confval::SValidator<float>::SVFRangeIn (0., 20.)),
+		confval::SValidator<float>("Common.OperatingRangeUpto",		&operating_range_upto,			confval::SValidator<float>::SVFRangeIn (0., 20.)),
 	}),
-	browse_command ("rox")
+	pagesize_item_saved (pagesize_item),
+	binsize_item_saved (binsize_item),
+	browse_command ("thunar")
 {
 	if ( construct_widgets() )
 		throw runtime_error ("SExpDesignUI::SExpDesignUI(): failed to construct widgets");
@@ -142,33 +163,30 @@ aghui::SExpDesignUI::SExpDesignUI( const string& dir)
 
 	chooser.hist_filename = string (getenv("HOME")) + "/.config/aghermann/sessionrc";
 
+	set_wMainWindow_interactive( false);
 	gtk_widget_show_all( (GtkWidget*)wMainWindow);
 
-	set_wMainWindow_interactive( false);
 	ED = new agh::CExpDesign( dir.empty()
 				  ? (chooser_read_histfile(), chooser_get_dir())
 				  : dir,
-				  {bind( &SExpDesignUI::sb_progress_indicator, this, _1, _2, _3)});
-	// if ( not ED->error_log().empty() ) {
-	// 	gtk_text_buffer_set_text( gtk_text_view_get_buffer( lScanLog),
-	// 				  ED->error_log().c_str(), -1);
-	// 	gtk_widget_show_all( (GtkWidget*)wScanLog);
-	// }
-
+				  {bind( &SExpDesignUI::sb_main_progress_indicator, this,
+					 placeholders::_1, placeholders::_2, placeholders::_3)});
 	nodestroy_by_cb = false;
 
+	fft_params_welch_window_type_saved	= ED->fft_params.welch_window_type;
+	af_dampen_window_type_saved		= ED->af_dampen_window_type;
+	af_dampen_factor_saved			= ED->af_dampen_factor;
+	mc_params_saved				= ED->mc_params;
+
 	if ( populate( true) )
 		;
-	pagesize_item_saved		= pagesize_item;
-	binsize_item_saved		= binsize_item;
-	FFTWindowType_saved		= ED->fft_params.welch_window_type;
-	AfDampingWindowType_saved	= ED->af_dampen_window_type;
 
 	set_wMainWindow_interactive( true);
 }
 
 
-aghui::SExpDesignUI::~SExpDesignUI()
+aghui::SExpDesignUI::
+~SExpDesignUI()
 {
 	delete ED;
 	if ( finalize_ui ) {
@@ -181,7 +199,8 @@ aghui::SExpDesignUI::~SExpDesignUI()
 }
 
 void
-aghui::SExpDesignUI::shutdown()
+aghui::SExpDesignUI::
+shutdown()
 {
 	// check if any facilities are open, and prompt?
 	// let the destructor handle all the saving
@@ -196,12 +215,13 @@ aghui::SExpDesignUI::shutdown()
 
 
 void
-aghui::SExpDesignUI::set_wMainWindow_interactive( bool indeed, bool flush)
+aghui::SExpDesignUI::
+set_wMainWindow_interactive( bool indeed, bool flush)
 {
 	set_cursor_busy( not indeed, (GtkWidget*)wMainWindow);
 	//gtk_widget_set_sensitive( (GtkWidget*)wMainWindow, indeed);
 
-	gtk_widget_set_sensitive( (GtkWidget*)cMsmtFreqRange, indeed);
+	gtk_widget_set_sensitive( (GtkWidget*)cMsmtProfileParamsContainer, indeed);
 	gtk_widget_set_sensitive( (GtkWidget*)cMeasurements, indeed);
 
 	gtk_widget_set_visible( (GtkWidget*)lTaskSelector2, indeed);
@@ -219,7 +239,8 @@ aghui::SExpDesignUI::set_wMainWindow_interactive( bool indeed, bool flush)
 
 
 int
-aghui::SExpDesignUI::populate( bool do_load)
+aghui::SExpDesignUI::
+populate( bool do_load)
 {
 	printf( "\nSExpDesignUI::populate():\n");
 	AghDD = ED->enumerate_sessions();
@@ -232,6 +253,7 @@ aghui::SExpDesignUI::populate( bool do_load)
 	_AghTi = AghTT.begin();
 	AghEE = ED->enumerate_episodes();
 	_AghEi = AghEE.begin();
+
 	printf( "*     Sessions: %s\n"
 		"*       Groups: %s\n"
 		"* All Channels: %s\n"
@@ -243,25 +265,51 @@ aghui::SExpDesignUI::populate( bool do_load)
 		string_join( AghTT, "; ").c_str(),
 		string_join( AghEE, "; ").c_str());
 
+	used_samplerates =
+		ED->used_samplerates();
+	used_eeg_samplerates =
+		ED->used_samplerates( sigfile::SChannel::TType::eeg);
+	if ( used_eeg_samplerates.size() == 1 )
+		printf( "* single common EEG samplerate: %zu\n", used_eeg_samplerates.front());
+	else
+		printf( "* multiple EEG samplerates (%zu)\n", used_eeg_samplerates.size());
+
 	if ( do_load ) {
 		if ( load_settings() )
 			;
 		if ( geometry.w > 0 ) {// implies the rest are, too
 			// gtk_window_parse_geometry( wMainWindow, _geometry_placeholder.c_str());
-			gtk_window_resize( wMainWindow, geometry.w, geometry.h);
 			gtk_window_move( wMainWindow, geometry.x, geometry.y);
+			gtk_window_resize( wMainWindow, geometry.w, geometry.h);
 		}
 	}
 
 	if ( AghGG.empty() ) {
 		show_empty_experiment_blurb();
+		gtk_widget_set_visible( (GtkWidget*)lTaskSelector2, FALSE);
+		gtk_widget_set_visible( (GtkWidget*)cMsmtMainToolbar, FALSE);
+		gtk_widget_set_visible( gtk_notebook_get_nth_page( tTaskSelector, 1), FALSE);
 	} else {
+		gtk_window_set_title( wMainWindow,
+				      (string ("Aghermann: ") + homedir2tilda( ED->session_dir())).c_str());
 		populate_mChannels();
 		populate_mSessions();
 		populate_mGlobalAnnotations();
 		populate_1();
 
-		gtk_widget_grab_focus( (GtkWidget*)eMsmtPSDFreqFrom);
+		if ( display_profile_type == sigfile::TMetricType::Psd ) {
+			gtk_combo_box_set_active( eMsmtProfileType, 0);
+			gtk_widget_set_visible( (GtkWidget*)cMsmtProfileParams2, FALSE);
+			gtk_widget_set_visible( (GtkWidget*)cMsmtProfileParams1, TRUE);
+			gtk_widget_grab_focus( (GtkWidget*)eMsmtOpFreqFrom);
+		} else {
+			gtk_combo_box_set_active( eMsmtProfileType, 1);
+			gtk_widget_set_visible( (GtkWidget*)cMsmtProfileParams1, FALSE);
+			gtk_widget_set_visible( (GtkWidget*)cMsmtProfileParams2, TRUE);
+		}
+		gtk_widget_set_visible( (GtkWidget*)lTaskSelector2, TRUE);
+		gtk_widget_set_visible( (GtkWidget*)cMsmtMainToolbar, TRUE);
+		gtk_widget_set_visible( gtk_notebook_get_nth_page( tTaskSelector, 1), TRUE);
 	}
 
 	if ( not ED->error_log().empty() ) {
@@ -275,7 +323,8 @@ aghui::SExpDesignUI::populate( bool do_load)
 
 
 void
-aghui::SExpDesignUI::depopulate( bool do_save)
+aghui::SExpDesignUI::
+depopulate( bool do_save)
 {
 	if ( do_save )
 		save_settings();
@@ -307,19 +356,22 @@ aghui::SExpDesignUI::depopulate( bool do_save)
 
 
 void
-aghui::SExpDesignUI::do_rescan_tree( bool ensure)
+aghui::SExpDesignUI::
+do_rescan_tree( bool ensure)
 {
 	set_wMainWindow_interactive( false);
 
 	depopulate( false);
 	ED -> sync();
 	if ( ensure )
-		ED -> scan_tree( {bind (&SExpDesignUI::sb_progress_indicator, this, _1, _2, _3)});
+		ED -> scan_tree( {bind (&SExpDesignUI::sb_main_progress_indicator, this,
+					placeholders::_1, placeholders::_2, placeholders::_3)});
 	else
 		ED -> scan_tree();
 	populate( false);
 
-	gtk_statusbar_push( sbMainStatusBar, sbContextIdGeneral,
+	gtk_statusbar_pop( sbMainStatusBar, sbMainContextIdGeneral);
+	gtk_statusbar_push( sbMainStatusBar, sbMainContextIdGeneral,
 			    "Scanning complete");
 
 	set_wMainWindow_interactive( true);
@@ -329,7 +381,8 @@ aghui::SExpDesignUI::do_rescan_tree( bool ensure)
 
 
 void
-aghui::SExpDesignUI::populate_mSessions()
+aghui::SExpDesignUI::
+populate_mSessions()
 {
 	g_signal_handler_block( eMsmtSession, eMsmtSession_changed_cb_handler_id);
 	gtk_list_store_clear( mSessions);
@@ -350,7 +403,8 @@ aghui::SExpDesignUI::populate_mSessions()
 
 
 void
-aghui::SExpDesignUI::populate_mChannels()
+aghui::SExpDesignUI::
+populate_mChannels()
 {
 	g_signal_handler_block( eMsmtChannel, eMsmtChannel_changed_cb_handler_id);
 	gtk_list_store_clear( mEEGChannels);
@@ -382,7 +436,8 @@ aghui::SExpDesignUI::populate_mChannels()
 
 
 void
-aghui::SExpDesignUI::__reconnect_channels_combo()
+aghui::SExpDesignUI::
+__reconnect_channels_combo()
 {
 	gtk_combo_box_set_model( eMsmtChannel, (GtkTreeModel*)mEEGChannels);
 
@@ -397,7 +452,8 @@ aghui::SExpDesignUI::__reconnect_channels_combo()
 
 
 void
-aghui::SExpDesignUI::__reconnect_sessions_combo()
+aghui::SExpDesignUI::
+__reconnect_sessions_combo()
 {
 	gtk_combo_box_set_model( eMsmtSession, (GtkTreeModel*)mSessions);
 
@@ -413,7 +469,43 @@ aghui::SExpDesignUI::__reconnect_sessions_combo()
 
 
 void
-aghui::SExpDesignUI::populate_mGlobalAnnotations()
+aghui::SExpDesignUI::
+__adjust_op_freq_spinbuttons()
+{
+	suppress_redraw = true;
+
+	switch ( display_profile_type ) {
+	case sigfile::Psd:
+		gtk_adjustment_set_step_increment( jMsmtOpFreqFrom,  ED->fft_params.binsize);
+		gtk_adjustment_set_step_increment( jMsmtOpFreqWidth, ED->fft_params.binsize);
+		if ( not used_eeg_samplerates.empty() )
+			gtk_adjustment_set_upper(
+				jMsmtOpFreqFrom,
+				ED->fft_params.binsize * (ED->fft_params.compute_n_bins( used_eeg_samplerates.back()) - 1));
+
+		gtk_widget_set_sensitive( (GtkWidget*)eMsmtOpFreqWidth, TRUE);
+	    break;
+	case sigfile::Mc:
+		gtk_adjustment_set_step_increment( jMsmtOpFreqFrom, ED->mc_params.bandwidth);
+		gtk_spin_button_set_value( eMsmtOpFreqWidth, ED->mc_params.bandwidth);
+		if ( not used_eeg_samplerates.empty() )
+			gtk_adjustment_set_upper(
+				jMsmtOpFreqFrom,
+				ED->mc_params.freq_from
+				+ ED->mc_params.bandwidth * (ED->mc_params.compute_n_bins( used_eeg_samplerates.back()) - 1));
+
+		gtk_widget_set_sensitive( (GtkWidget*)eMsmtOpFreqWidth, FALSE);
+	    break;
+	}
+
+	suppress_redraw = false;
+}
+
+
+
+void
+aghui::SExpDesignUI::
+populate_mGlobalAnnotations()
 {
 	gtk_tree_store_clear( mGlobalAnnotations);
       // apart from tree store, also refresh global list
@@ -491,20 +583,42 @@ aghui::SExpDesignUI::populate_mGlobalAnnotations()
 
 
 
+void
+aghui::SExpDesignUI::
+calculate_profile_scale()
+{
+	double	avg_profile_height = 0.;
+	size_t	valid_episodes = 0;
+	for ( auto& G : groups )
+		for ( auto &J : G )
+			if ( J.cscourse && !J.cscourse->mm_list().empty() ) {
+				avg_profile_height += J.cscourse->metric_avg();
+				++valid_episodes;
+			}
+	avg_profile_height /= valid_episodes;
+
+	switch ( display_profile_type ) {
+	case sigfile::TMetricType::Psd:
+		profile_scale_psd = timeline_height / avg_profile_height * .3;
+	    break;
+	case sigfile::TMetricType::Mc:
+		profile_scale_mc = timeline_height / avg_profile_height * .3;
+	    break;
+	}
+}
+
 
 void
-aghui::SExpDesignUI::populate_1()
+aghui::SExpDesignUI::
+populate_1()
 {
-	if ( ED->n_groups() == 0 )
+	if ( ED->groups.empty() )
 		return;
 
       // touch toolbar controls
-	g_signal_handler_block( eMsmtPSDFreqFrom, eMsmtPSDFreqFrom_value_changed_cb_handler_id);
-	g_signal_handler_block( eMsmtPSDFreqWidth, eMsmtPSDFreqWidth_value_changed_cb_handler_id);
-	gtk_spin_button_set_value( eMsmtPSDFreqFrom, operating_range_from);
-	gtk_spin_button_set_value( eMsmtPSDFreqWidth, operating_range_upto - operating_range_from);
-	g_signal_handler_unblock( eMsmtPSDFreqFrom, eMsmtPSDFreqFrom_value_changed_cb_handler_id);
-	g_signal_handler_unblock( eMsmtPSDFreqWidth, eMsmtPSDFreqWidth_value_changed_cb_handler_id);
+	suppress_redraw = true;
+	gtk_spin_button_set_value( eMsmtOpFreqFrom, operating_range_from);
+	gtk_spin_button_set_value( eMsmtOpFreqWidth, operating_range_upto - operating_range_from);
 
       // deal with the main drawing area
 	groups.clear();
@@ -512,11 +626,12 @@ aghui::SExpDesignUI::populate_1()
 			       (GtkCallback)gtk_widget_destroy,
 			       NULL);
 
+	printf( "SExpDesignUI::populate_1(): session \"%s\", channel \"%s\"\n", AghD(), AghT());
+
 	time_t	earliest_start = (time_t)-1,
 		latest_end = (time_t)-1;
-
-	printf( "SExpDesignUI::populate_1(): session \"%s\", channel \"%s\"\n", AghD(), AghT());
-      // first pass: determine common timeline
+      // first pass: (1) create SSubjectPresentation's
+      //             (2) determine common timeline
 	for ( auto Gi = ED->groups.begin(); Gi != ED->groups.end(); ++Gi ) {
 		groups.emplace_back( Gi, *this); // precisely need the iterator, not object by reference
 		SGroupPresentation& Gp = groups.back();
@@ -526,6 +641,7 @@ aghui::SExpDesignUI::populate_1()
 			if ( j.cscourse && J.have_session(*_AghDi) ) {
 				auto& ee = J.measurements[*_AghDi].episodes;
 				if ( not ee.empty() ) {
+					// (2)
 					if ( earliest_start == (time_t)-1 || earliest_start > ee.front().start_rel )
 						earliest_start = ee.front().start_rel;
 					if ( latest_end == (time_t)-1 || latest_end < ee.back().end_rel )
@@ -535,14 +651,17 @@ aghui::SExpDesignUI::populate_1()
 						 AghD(), AghT(), J.name());
 			}
 		}
-	};
+	}
 
 	timeline_start = earliest_start;
 	timeline_end   = latest_end;
 	timeline_width = (timeline_end - timeline_start) / 3600 * timeline_pph;
-	timeline_pages = (timeline_end - timeline_start) / ED->fft_params.page_size;
+	timeline_pages = (timeline_end - timeline_start) / ED->fft_params.pagesize;
 
-	fprintf( stderr, "SExpDesignUI::populate_1(): common timeline:\n");
+	if ( profile_scale_psd == 0. || profile_scale_mc == 0. ) // not previously saved
+		calculate_profile_scale();
+
+	printf( "SExpDesignUI::populate_1(): common timeline:\n");
 	fputs( asctime( localtime(&earliest_start)), stderr);
 	fputs( asctime( localtime(&latest_end)), stderr);
 
@@ -585,7 +704,7 @@ aghui::SExpDesignUI::populate_1()
 		gtk_box_pack_start( (GtkBox*)cMeasurements,
 				    (GtkWidget*)G.expander, FALSE, TRUE, 3);
 		gtk_container_add( (GtkContainer*)G.expander,
-				   (GtkWidget*) (G.vbox = (GtkExpander*)gtk_vbox_new( TRUE, 1)));
+				   (GtkWidget*) (G.vbox = (GtkExpander*)gtk_box_new( GTK_ORIENTATION_VERTICAL, 1)));
 		g_object_set( (GObject*)G.vbox,
 			      "height-request", -1,
 			      NULL);
@@ -611,6 +730,7 @@ aghui::SExpDesignUI::populate_1()
 					       (GdkEventMask)
 					       GDK_EXPOSURE_MASK |
 					       GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
+					       GDK_SCROLL_MASK |
 					       GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK |
 					       GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
 					       GDK_POINTER_MOTION_MASK);
@@ -626,20 +746,18 @@ aghui::SExpDesignUI::populate_1()
 			g_signal_connect( J.da, "scroll-event",
 					  (GCallback)daSubjectTimeline_scroll_event_cb,
 					  &J);
-			if ( J.cscourse ) {
-				g_signal_connect( J.da, "button-press-event",
-						  (GCallback)daSubjectTimeline_button_press_event_cb,
-						  &J);
-				g_signal_connect( J.da, "motion-notify-event",
-						  (GCallback)daSubjectTimeline_motion_notify_event_cb,
-						  &J);
-			}
+			g_signal_connect( J.da, "button-press-event",
+					  (GCallback)daSubjectTimeline_button_press_event_cb,
+					  &J);
+			g_signal_connect( J.da, "motion-notify-event",
+					  (GCallback)daSubjectTimeline_motion_notify_event_cb,
+					  &J);
 
 			g_signal_connect( J.da, "drag-data-received",
-					  (GCallback)cMeasurements_drag_data_received_cb,
+					  (GCallback)common_drag_data_received_cb,
 					  this);
 			g_signal_connect( J.da, "drag-drop",
-					  (GCallback)cMeasurements_drag_drop_cb,
+					  (GCallback)common_drag_drop_cb,
 					  this);
 			gtk_drag_dest_set( J.da, GTK_DEST_DEFAULT_ALL,
 					   NULL, 0, GDK_ACTION_COPY);
@@ -658,12 +776,13 @@ aghui::SExpDesignUI::populate_1()
 				      "width-request", timeline_width + tl_left_margin + tl_right_margin,
 				      NULL);
 
-	snprintf_buf( "<b><small>page: %zu sec  Bin: %g Hz  %s</small></b>",
-		      ED->fft_params.page_size,
-		      ED->fft_params.bin_size,
+	snprintf_buf( "<small>%zusec/%gHz/%s</small>",
+		      ED->fft_params.pagesize,
+		      ED->fft_params.binsize,
 		      sigfile::SFFTParamSet::welch_window_type_name( ED->fft_params.welch_window_type));
-	gtk_label_set_markup( lMsmtInfo, __buf__);
+	gtk_label_set_markup( lMsmtPSDInfo, __buf__);
 
+	suppress_redraw = false;
 //	set_cursor_busy( false, (GtkWidget*)wMainWindow);
 	gtk_widget_show_all( (GtkWidget*)(cMeasurements));
 }
@@ -671,7 +790,8 @@ aghui::SExpDesignUI::populate_1()
 
 
 void
-aghui::SExpDesignUI::show_empty_experiment_blurb()
+aghui::SExpDesignUI::
+show_empty_experiment_blurb()
 {
 	gtk_container_foreach( (GtkContainer*)cMeasurements,
 			       (GtkCallback) gtk_widget_destroy,
@@ -690,9 +810,7 @@ aghui::SExpDesignUI::show_empty_experiment_blurb()
 		" press the button below to download it into the current directory:";
 	GtkLabel *blurb_label = (GtkLabel*)gtk_label_new( "");
 	gtk_label_set_markup( blurb_label, blurb);
-	gtk_widget_set_visible( (GtkWidget*)lTaskSelector2, FALSE);
-	gtk_widget_set_visible( (GtkWidget*)cMsmtFreqRange, FALSE);
-	gtk_widget_set_visible( gtk_notebook_get_nth_page( tTaskSelector, 1), FALSE);
+
 	gtk_box_pack_start( (GtkBox*)cMeasurements,
 			    (GtkWidget*)blurb_label,
 			    TRUE, TRUE, 0);
@@ -725,7 +843,8 @@ bDownload_clicked_cb( GtkButton* button, gpointer userdata)
 }
 
 int
-aghui::SExpDesignUI::try_download()
+aghui::SExpDesignUI::
+try_download()
 {
 	const char
 		*url = "http://johnhommer.com/academic/code/aghermann/Experiment.tar.bz2",
@@ -773,26 +892,29 @@ aghui::SExpDesignUI::try_download()
 
 
 void
-aghui::SExpDesignUI::buf_on_status_bar( bool ensure)
+aghui::SExpDesignUI::
+buf_on_main_status_bar( bool ensure)
 {
-	gtk_statusbar_pop( sbMainStatusBar, sbContextIdGeneral);
-	gtk_statusbar_push( sbMainStatusBar, sbContextIdGeneral, __buf__);
+	gtk_statusbar_pop( sbMainStatusBar, sbMainContextIdGeneral);
+	gtk_statusbar_push( sbMainStatusBar, sbMainContextIdGeneral, __buf__);
 	if ( ensure )
 		aghui::gtk_flush();
 }
 
 void
-aghui::SExpDesignUI::sb_progress_indicator( const char* current, size_t n, size_t i)
+aghui::SExpDesignUI::
+sb_main_progress_indicator( const char* current, size_t n, size_t i)
 {
 	snprintf_buf( "(%zu of %zu) %s", i, n, current);
-	buf_on_status_bar( true);
+	buf_on_main_status_bar( true);
 }
 
 
 
 
 void
-aghui::SExpDesignUI::update_subject_details_interactively( agh::CSubject& J)
+aghui::SExpDesignUI::
+update_subject_details_interactively( agh::CSubject& J)
 {
 	gtk_entry_set_text( eSubjectDetailsName, J.full_name.c_str());
 	gtk_spin_button_set_value( eSubjectDetailsAge, J.age);
