@@ -34,8 +34,9 @@ inline namespace {
 
 
 void
-aghui::SScoringFacility::SChannel::draw_signal( const valarray<TFloat>& signal,
-						unsigned width, int vdisp, cairo_t *cr) const
+aghui::SScoringFacility::SChannel::
+draw_signal( const valarray<TFloat>& signal,
+	     unsigned width, int vdisp, cairo_t *cr) const
 {
 	size_t	start = _p.cur_vpage_start() * samplerate(),
 		end   = _p.cur_vpage_end()   * samplerate(),
@@ -68,17 +69,18 @@ aghui::SScoringFacility::SChannel::draw_signal( const valarray<TFloat>& signal,
 
 
 void
-aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
-						     int wd, int y0,
-						     bool draw_marquee) const
+aghui::SScoringFacility::SChannel::
+draw_page_static( cairo_t *cr,
+		  int wd, int y0,
+		  bool draw_marquee) const
 {
 	int	ptop = y0 - _p.interchannel_gap/2,
 		pbot = ptop + _p.interchannel_gap;
 
       // marquee, goes first, not to obscure waveforms
 	if ( draw_marquee // possibly undesired (such as when drawing for unfazer)
-	     && overlap( selection_start_time, selection_end_time,
-			 _p.cur_xvpage_start(), _p.cur_xvpage_end()) ) {
+	     && agh::overlap( selection_start_time, selection_end_time,
+			      _p.cur_xvpage_start(), _p.cur_xvpage_end()) ) {
 		double	pre = _p.skirting_run_per1 * _p.vpagesize(),
 			ma = (selection_start_time - _p.cur_xvpage_start()) / _p.xvpagesize() * wd,
 			me = (selection_end_time   - _p.cur_xvpage_start()) / _p.xvpagesize() * wd;
@@ -143,7 +145,7 @@ aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
 		draw_signal_filtered( wd, y0, cr);
 
 		_p._p.CwB[SExpDesignUI::TColour::labels_sf].set_source_rgb( cr);
-		cairo_move_to( cr, wd-120, y0 - 15);
+		cairo_move_to( cr, wd-88, y0 - 15);
 		cairo_set_font_size( cr, 10);
 		snprintf_buf( "filt");
 		cairo_show_text( cr, __buf__);
@@ -163,7 +165,7 @@ aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
 		draw_signal_original( wd, y0, cr);
 
 		_p._p.CwB[SExpDesignUI::TColour::labels_sf].set_source_rgb( cr);
-		cairo_move_to( cr, wd-120, y0 - 25);
+		cairo_move_to( cr, wd-88, y0 - 25);
 		cairo_set_font_size( cr, 10);
 		snprintf_buf( "orig");
 		cairo_show_text( cr, __buf__);
@@ -206,7 +208,7 @@ aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
 			_p._p.CwB[SExpDesignUI::TColour::artifact].set_source_rgba( cr,  // do some gradients perhaps?
 										    .4);
 			for ( auto &A : Aa() ) {
-				if ( overlap( (int)A.first, (int)A.second, cvpa, cvpe) ) {
+				if ( agh::overlap( (int)A.first, (int)A.second, cvpa, cvpe) ) {
 					int	aa = (int)A.first - cvpa,
 						ae = (int)A.second - cvpa;
 					if ( aa < 0 )    aa = 0;
@@ -234,11 +236,11 @@ aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
 		if ( not Aa.empty() ) {
 			int on_this_page = 0;
 			for ( auto &A : Aa ) {
-				if ( overlap( (int)A.span.first, (int)A.span.second, cvpa, cvpe) ) {
-					int disp = pbot - ++on_this_page * 5;
-					cairo_pattern_t *cp = cairo_pattern_create_linear( 0., disp, 0., disp-30);
-					_p._p.CwB[SExpDesignUI::TColour::annotations].pattern_add_color_stop_rgba( cp, 0.);
-					_p._p.CwB[SExpDesignUI::TColour::annotations].pattern_add_color_stop_rgba( cp, .15, 0.1);
+				if ( agh::overlap( (int)A.span.first, (int)A.span.second, cvpa, cvpe) ) {
+					int disp = ptop + ++on_this_page * 5;
+					cairo_pattern_t *cp = cairo_pattern_create_linear( 0., disp, 0., pbot);
+					_p._p.CwB[SExpDesignUI::TColour::annotations].pattern_add_color_stop_rgba( cp, 0., 1.);
+					_p._p.CwB[SExpDesignUI::TColour::annotations].pattern_add_color_stop_rgba( cp, .1, 0.3);
 					_p._p.CwB[SExpDesignUI::TColour::annotations].pattern_add_color_stop_rgba( cp, 1., 0.);
 					cairo_set_source( cr, cp);
 
@@ -247,16 +249,16 @@ aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
 					if ( aa < 0 )    aa = 0;
 					if ( ae > evpz ) ae = evpz;
 					cairo_rectangle( cr,
-							 (float)(aa % evpz) / evpz * wd, disp-50,
-							 (float)(ae - aa) / evpz * wd, 50);
+							 (float)(aa % evpz) / evpz * wd, disp,
+							 (float)(ae - aa) / evpz * wd, pbot-ptop);
 					cairo_fill( cr);
 					cairo_stroke( cr);
 					cairo_pattern_destroy( cp);
 
 					cairo_select_font_face( cr, "serif", CAIRO_FONT_SLANT_ITALIC, CAIRO_FONT_WEIGHT_NORMAL);
-					cairo_set_font_size( cr, 10);
+					cairo_set_font_size( cr, 11);
 					cairo_set_source_rgb( cr, 0., 0., 0.);
-					cairo_move_to( cr, (float)(aa % evpz) / evpz * wd, disp - 4);
+					cairo_move_to( cr, (float)(aa % evpz) / evpz * wd, disp + 12);
 					cairo_show_text( cr, A.label.c_str());
 				} else if ( (int)A.span.first > cvpe )  // no more artifacts up to and on current page
 					break;
@@ -269,9 +271,9 @@ aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
 	{
 		snprintf_buf( "[%s] %s", sigfile::SChannel::kemp_signal_types[type], name);
 
-		cairo_select_font_face( cr, "serif", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-		cairo_set_font_size( cr, 10);
-		cairo_set_source_rgb( cr, 0., 0., 0.);
+		cairo_select_font_face( cr, "serif", CAIRO_FONT_SLANT_ITALIC, CAIRO_FONT_WEIGHT_BOLD);
+		cairo_set_font_size( cr, 13);
+		cairo_set_source_rgba( cr, 0., 0., 0., 0.7);
 		cairo_move_to( cr, 10, y0 - 14);
 		cairo_show_text( cr, __buf__);
 		cairo_stroke( cr);
@@ -321,20 +323,22 @@ aghui::SScoringFacility::SChannel::draw_page_static( cairo_t *cr,
 
 
 void
-aghui::SScoringFacility::SChannel::draw_page( const char *fname, int width, int height) // to a file
+aghui::SScoringFacility::SChannel::
+draw_page( const char *fname, int width, int height) // to a file
 {
 #ifdef CAIRO_HAS_SVG_SURFACE
-	 cairo_surface_t *cs = cairo_svg_surface_create( fname, width, height);
-	 cairo_t *cr = cairo_create( cs);
-	 draw_page_static( cr, width, height/2, false);
-	 cairo_destroy( cr);
-	 cairo_surface_destroy( cs);
+	cairo_surface_t *cs = cairo_svg_surface_create( fname, width, height);
+	cairo_t *cr = cairo_create( cs);
+	draw_page_static( cr, width, height/2, false);
+	cairo_destroy( cr);
+	cairo_surface_destroy( cs);
 #endif
 }
 
 
 void
-aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
+aghui::SScoringFacility::SChannel::
+draw_page( cairo_t* cr)
 {
 	if ( hidden )
 		return;
@@ -348,7 +352,7 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 
        // PSD profile
 	if ( _p.mode == TMode::scoring and
-	     draw_power and type == sigfile::SChannel::TType::eeg ) {
+	     draw_psd and type == sigfile::SChannel::TType::eeg ) {
 		overlay = true;
 
 		cairo_set_line_width( cr, 1.);
@@ -356,23 +360,23 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 		guint i;
 
 		if ( draw_bands ) {
-			for ( size_t b = sigfile::TBand::delta; b != uppermost_band; ++b ) {
-				auto& P = power_in_bands[b];
+			for ( size_t b = sigfile::TBand::delta; b <= psd.uppermost_band; ++b ) {
+				auto& P = psd.course_in_bands[b];
 				_p._p.CwB[SExpDesignUI::band2colour((sigfile::TBand)b)].set_source_rgba( cr, .5);
 				double zero = 0.5 / P.size() * _p.da_wd;
 				cairo_move_to( cr, zero,
-					       - P[0] * power_display_scale + pbot);
+					       - P[0] * psd.display_scale + pbot);
 				for ( i = 1; i < P.size(); ++i )
 					cairo_line_to( cr, ((double)i+0.5) / P.size() * _p.da_wd,
-						       - P[i] * power_display_scale + pbot);
-				if ( b == focused_band ) {
+						       - P[i] * psd.display_scale + pbot);
+				if ( b == psd.focused_band ) {
 					cairo_line_to( cr, _p.da_wd, pbot);
 					cairo_line_to( cr,     zero, pbot);
 					cairo_fill( cr);
 				}
 				cairo_stroke( cr);
 
-				if ( b == focused_band ) {
+				if ( b == psd.focused_band ) {
 					cairo_select_font_face( cr, "sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
 					snprintf_buf( "%s %g–%g",
 						      _p._p.FreqBandNames[(unsigned)b],
@@ -381,45 +385,129 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 					cairo_select_font_face( cr, "sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
 					snprintf_buf( "%s", _p._p.FreqBandNames[(unsigned)b]);
 				}
-				cairo_move_to( cr, _p.da_wd - 70,
-					       ptop + (int)uppermost_band*12 - 12*(unsigned)b + 12);
+				cairo_move_to( cr, _p.da_wd - 170,
+					       ptop + psd.uppermost_band*12 - 12*(unsigned)b + 12);
 				cairo_show_text( cr, __buf__);
 				cairo_stroke( cr);
 			}
 		} else {
-			_p._p.CwB[SExpDesignUI::TColour::power_sf].set_source_rgba( cr, .5);
-			double zero = 0.5 / power.size() * _p.da_wd;
+			_p._p.CwB[SExpDesignUI::TColour::profile_psd_sf].set_source_rgba( cr, .5);
+			double zero = 0.5 / psd.course.size() * _p.da_wd;
 			cairo_move_to( cr, zero,
-				       power[0]);
-			for ( i = 0; i < power.size(); ++i )
-				cairo_line_to( cr, ((double)i+.5) / power.size() * _p.da_wd,
-					       - power[i] * power_display_scale + pbot);
+				       psd.course[0]);
+			for ( i = 0; i < psd.course.size(); ++i )
+				cairo_line_to( cr, ((double)i+.5) / psd.course.size() * _p.da_wd,
+					       - psd.course[i] * psd.display_scale + pbot);
 			cairo_line_to( cr, _p.da_wd, pbot);
 			cairo_line_to( cr,     zero, pbot);
 			cairo_fill( cr);
 			cairo_stroke( cr);
 
 			cairo_select_font_face( cr, "sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-			snprintf_buf( "%g–%g Hz", from, upto);
-			cairo_move_to( cr, _p.da_wd - 70, pbot - 15);
+			snprintf_buf( "%g–%g Hz", psd.from, psd.upto);
+			cairo_move_to( cr, _p.da_wd - 170, pbot - 15);
 			cairo_show_text( cr, __buf__);
 			cairo_stroke( cr);
 		}
 
+		if ( draw_spectrum and _p.pagesize_is_right() ) {
+			guint	gx = 120,
+				gy = ptop + 25,
+				gh = min( 60u, pbot - ptop - 5),
+				gw  = 80;
+			size_t	m;
+
+			cairo_set_source_rgba( cr, 1., 1., 1., .8);
+			cairo_rectangle( cr, gx-15, gy-5, gw+15+5, gh+5+5);
+			cairo_fill( cr);
+
+			// grid lines
+			_p._p.CwB[SExpDesignUI::TColour::spectrum_grid].set_source_rgba( cr, .1);
+			cairo_set_line_width( cr, .3);
+			for ( size_t i = 1; i < last_spectrum_bin; ++i ) {
+				cairo_move_to( cr, gx + (float)i/last_spectrum_bin * gw, gy);
+				cairo_rel_line_to( cr, 0, gh);
+			}
+			cairo_stroke( cr);
+
+			// spectrum
+			_p._p.CwB[SExpDesignUI::TColour::spectrum].set_source_rgba( cr, .8);
+			cairo_set_line_width( cr, 2);
+			float factor = psd.display_scale / crecording.binsize;
+			cairo_move_to( cr,
+				       gx, gy + gh - (2 + spectrum[0] * factor));
+			for ( m = 1; m < last_spectrum_bin; ++m ) {
+				cairo_line_to( cr,
+					       gx + (float)m / last_spectrum_bin * gw,
+					       gy + gh - spectrum[m] * factor);
+			}
+			cairo_stroke( cr);
+
+			// axes
+			_p._p.CwB[SExpDesignUI::TColour::spectrum_axes].set_source_rgba( cr, .5);
+			cairo_set_line_width( cr, .5);
+			cairo_move_to( cr, gx, gy);
+			cairo_rel_line_to( cr, 0, gh);
+			cairo_rel_line_to( cr, gw, 0);
+
+			// y ticks
+			m = 0;
+			while ( (++m * 1e6) < gh / factor ) {
+				cairo_move_to( cr, gx-3,  gy + gh - (2 + (float)m*1e6 * factor));
+				cairo_rel_line_to( cr, 3, 0);
+			}
+			cairo_stroke( cr);
+
+			// labels
+			cairo_text_extents_t extents;
+			_p._p.CwB[SExpDesignUI::TColour::labels_sf].set_source_rgba( cr);
+			cairo_set_font_size( cr, 8);
+
+			snprintf_buf( "%g Hz",
+				      last_spectrum_bin * crecording.binsize);
+//				      draw_spectrum_absolute ? 'A' : 'R');
+			cairo_text_extents( cr, __buf__, &extents);
+			cairo_move_to( cr,
+				       gx + gw - extents.width - 5,
+				       gy + 4);
+			cairo_show_text( cr, __buf__);
+			cairo_stroke( cr);
+		}
+	}
+
+	if ( _p.mode == TMode::scoring and
+	     draw_mc and type == sigfile::SChannel::TType::eeg ) {
+		overlay = true;
+
+		cairo_set_line_width( cr, 1.);
+		cairo_set_font_size( cr, 10);
+		guint i;
+
+		_p._p.CwB[SExpDesignUI::TColour::profile_mc_sf].set_source_rgba( cr, .5);
+		double zero = 0.5 / mc.course.size() * _p.da_wd;
+		cairo_move_to( cr, zero,
+			       mc.course[0]);
+		for ( i = 0; i < mc.course.size(); ++i )
+			cairo_line_to( cr, ((double)i+.5) / mc.course.size() * _p.da_wd,
+				       - mc.course[i] * mc.display_scale + pbot);
+		cairo_line_to( cr, _p.da_wd, pbot);
+		cairo_line_to( cr,     zero, pbot);
+		cairo_fill( cr);
+		cairo_stroke( cr);
+
+		cairo_select_font_face( cr, "sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
+		snprintf_buf( "%g–%g Hz",
+			      crecording.freq_from + (mc.bin  ) * crecording.bandwidth,
+			      crecording.freq_from + (mc.bin+1) * crecording.bandwidth);
+		cairo_move_to( cr, _p.da_wd - 70, pbot - 30);
+		cairo_show_text( cr, __buf__);
+		cairo_stroke( cr);
+
 		cairo_select_font_face( cr, "sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
 		cairo_set_font_size( cr, 9);
 
 	      // scale
-		cairo_set_source_rgba( cr, 0., 0., 0., .5);
-		cairo_set_line_width( cr, 1.5);
-		// cairo_set_line_cap( cr, CAIRO_LINE_CAP_BUTT); // is default
-		cairo_move_to( cr, 60, ptop + 10);
-		cairo_rel_line_to( cr, 0, power_display_scale * 1e6);
-		cairo_stroke( cr);
-
-		cairo_move_to( cr, 65, ptop + 20);
-		cairo_show_text( cr, "1 µV²/Hz");
-		cairo_stroke( cr);
+		// scale is balooney
 	}
 
       // EMG profile
@@ -435,7 +523,7 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 		for ( ; i < emg_profile.size(); ++i )
 			cairo_line_to( cr, i / dps,
 				       pbot - EMGProfileHeight/2 - emg_profile[i] * signal_display_scale/2);
-		for ( ; i > 0; --i )
+		for ( --i; i > 0; --i )
 			cairo_line_to( cr, i / dps,
 				       pbot - EMGProfileHeight/2 + emg_profile[i] * signal_display_scale/2);
 		cairo_fill( cr);
@@ -490,7 +578,7 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 	}
 
       // samples per pixel
-	if ( _p.mode == TMode::scoring and _p.draw_spp ) {
+	if ( _p.mode == TMode::scoring and resample_signal ) {
 		_p._p.CwB[SExpDesignUI::TColour::ticks_sf].set_source_rgb( cr);
 		cairo_select_font_face( cr, "sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
 		cairo_set_font_size( cr, 8);
@@ -506,7 +594,8 @@ aghui::SScoringFacility::SChannel::draw_page( cairo_t* cr)
 
 template <class T>
 void
-aghui::SScoringFacility::_draw_matrix_to_montage( cairo_t *cr, const itpp::Mat<T>& mat)
+aghui::SScoringFacility::
+_draw_matrix_to_montage( cairo_t *cr, const itpp::Mat<T>& mat)
 {
 	int gap = da_ht/mat.rows();
 	int our_y = gap/2;
@@ -595,7 +684,21 @@ aghui::SScoringFacility::_draw_matrix_to_montage( cairo_t *cr, const itpp::Mat<T
 }
 
 void
-aghui::SScoringFacility::draw_montage( cairo_t* cr)
+aghui::SScoringFacility::
+draw_montage( const char *fname) // to a file
+{
+#ifdef CAIRO_HAS_SVG_SURFACE
+	cairo_surface_t *cs = cairo_svg_surface_create( fname, da_wd, da_ht);
+	cairo_t *cr = cairo_create( cs);
+	draw_montage( cr);
+	cairo_destroy( cr);
+	cairo_surface_destroy( cs);
+#endif
+}
+
+void
+aghui::SScoringFacility::
+draw_montage( cairo_t* cr)
 {
 	double	true_frac = 1. - 1. / (1. + 2*skirting_run_per1);
 	size_t	half_pad = da_wd * true_frac/2,
