@@ -107,14 +107,13 @@ daSFMontage_button_press_event_cb( GtkWidget *wid, GdkEventButton *event, gpoint
 	auto Ch = SF.using_channel = SF.channel_near( event->y);
 
 	if ( Ch->type == sigfile::SChannel::TType::eeg &&
-	     Ch->draw_power && event->y > Ch->zeroy ) {
+	     (Ch->draw_psd || Ch->draw_mc) && event->y > Ch->zeroy ) {
 		switch ( event->button ) {
 		case 1:
 			if ( event->state & GDK_MODIFIER_MASK )
 				;
 			else
-				gtk_spin_button_set_value( SF.eSFCurrentPage,
-							   (event->x / SF.da_wd) * SF.total_vpages() + 1);
+				SF.set_cur_vpage( (event->x / SF.da_wd) * SF.total_vpages());
 			// will eventually call set_cur_vpage(), which will do redraw
 		    break;
 		case 2:
@@ -132,8 +131,7 @@ daSFMontage_button_press_event_cb( GtkWidget *wid, GdkEventButton *event, gpoint
 		    Ch->draw_emg && event->y > Ch->zeroy ) {
 		switch ( event->button ) {
 		case 1:
-			gtk_spin_button_set_value( SF.eSFCurrentPage,
-						   (event->x / SF.da_wd) * SF.total_vpages() + 1);
+			SF.set_cur_vpage( (event->x / SF.da_wd) * SF.total_vpages());
 		    break;
 		default:
 		    break;
@@ -142,11 +140,14 @@ daSFMontage_button_press_event_cb( GtkWidget *wid, GdkEventButton *event, gpoint
 	} else {
 		switch ( event->button ) {
 		case 2:
+			Ch->signal_display_scale =
+				Ch->calibrate_display_scale( Ch->draw_filtered_signal ? Ch->signal_filtered : Ch->signal_original,
+							     SF.vpagesize() * Ch->samplerate() * min (Ch->crecording.F().pages(), (size_t)10),
+							     SF.interchannel_gap / 2);
 			if ( event->state & GDK_CONTROL_MASK )
-				for ( auto H : SF.channels )
-					H.signal_display_scale = SF.sane_signal_display_scale;
-			else
-				Ch->signal_display_scale = SF.sane_signal_display_scale;
+				for ( auto& H : SF.channels )
+					H.signal_display_scale = Ch->signal_display_scale;
+
 			gtk_widget_queue_draw( wid);
 		    break;
 		case 3:
@@ -157,13 +158,14 @@ daSFMontage_button_press_event_cb( GtkWidget *wid, GdkEventButton *event, gpoint
 				double cpos = SF.time_at_click( event->x);
 				// hide ineffective items
 				SF.using_channel->update_channel_check_menu_items();
+				SF.using_channel->update_power_check_menu_items();
 				gtk_widget_set_visible( (GtkWidget*)SF.iSFPageHidden, SF.n_hidden > 0);
 				bool over_any =
 					not (SF.over_annotations = Ch->in_annotations( cpos)) . empty();
 				gtk_widget_set_visible( (GtkWidget*)SF.mSFPageAnnotation, over_any);
 				gtk_widget_set_visible( (GtkWidget*)SF.iSFPageAnnotationSeparator, over_any);
-				gtk_menu_popup( overlap( Ch->selection_start_time, Ch->selection_end_time,
-							 cpos, cpos) ? SF.mSFPageSelection : SF.mSFPage,
+				gtk_menu_popup( agh::overlap( Ch->selection_start_time, Ch->selection_end_time,
+							      cpos, cpos) ? SF.mSFPageSelection : SF.mSFPage,
 						NULL, NULL, NULL, NULL, 3, event->time);
 			}
 		    break;
@@ -286,9 +288,8 @@ daSFMontage_button_release_event_cb( GtkWidget *wid, GdkEventButton *event, gpoi
 						NULL, NULL, NULL, NULL, 3, event->time);
 			}
 		} else if ( Ch->type == sigfile::SChannel::TType::eeg &&
-			    Ch->draw_power && event->y > Ch->zeroy )
-			gtk_spin_button_set_value( SF.eSFCurrentPage,
-						   (event->x / SF.da_wd) * SF.total_vpages()+1);
+			    (Ch->draw_psd || Ch->draw_mc) && event->y > Ch->zeroy )
+			SF.set_cur_vpage( (event->x / SF.da_wd) * SF.total_vpages());
 		else {
 			SF.using_channel->marquee_to_selection();
 			SF.mode = aghui::SScoringFacility::TMode::scoring;
@@ -314,7 +315,8 @@ daSFMontage_scroll_event_cb( GtkWidget *wid, GdkEventScroll *event, gpointer use
 	auto& SF = *(SScoringFacility*)userdata;
 	auto Ch = SF.using_channel = SF.channel_near( event->y);
 
-	if ( event->state & GDK_MOD1_MASK ) {
+	if ( (event->state & GDK_MOD1_MASK) and
+	     not (event->state & GDK_SHIFT_MASK) ) {
 		auto da_ht0 = SF.da_ht;
 		switch ( event->direction ) {
 		case GDK_SCROLL_DOWN:
@@ -333,90 +335,124 @@ daSFMontage_scroll_event_cb( GtkWidget *wid, GdkEventScroll *event, gpointer use
 		default:
 		    break;
 		}
-		return TRUE;
-	}
 
-	if ( Ch->type == sigfile::SChannel::TType::eeg &&
-	     Ch->draw_power && event->y > Ch->zeroy ) {
-		if ( event->state & GDK_SHIFT_MASK ) {
+	} else if ( Ch->type == sigfile::SChannel::TType::eeg
+	     && event->y > Ch->zeroy
+	     && (Ch->draw_psd || Ch->draw_mc) ) {
+		if ( event->state & GDK_SHIFT_MASK && Ch->draw_psd )
 			switch ( event->direction ) {
 			case GDK_SCROLL_DOWN:
 				if ( Ch->draw_bands ) {
-					if ( Ch->focused_band != sigfile::TBand::delta ) {
-						--Ch->focused_band;
+					if ( Ch->psd.focused_band > sigfile::TBand::delta ) {
+						--Ch->psd.focused_band;
+						if ( Ch->autoscale_profile )
+							Ch->update_profile_display_scales();
 						gtk_widget_queue_draw( wid);
 					}
 				} else
-					if ( Ch->from > 0 ) {
-						Ch->from = Ch->from - .5;
-						Ch->upto = Ch->upto - .5;
-						Ch->get_power( false);
+					if ( Ch->psd.from > 0 ) {
+						Ch->psd.from -= .5;
+						Ch->psd.upto -= .5;
+						Ch->get_psd_course( false);
+						if ( Ch->autoscale_profile )
+							Ch->update_profile_display_scales();
 						gtk_widget_queue_draw( wid);
 					}
-			    break;
+				break;
 			case GDK_SCROLL_UP:
 				if ( Ch->draw_bands ) {
-					if ( Ch->focused_band != Ch->uppermost_band ) {
-						Ch->focused_band++;
+					if ( Ch->psd.focused_band < Ch->psd.uppermost_band ) {
+						++Ch->psd.focused_band;
+						if ( Ch->autoscale_profile )
+							Ch->update_profile_display_scales();
 						gtk_widget_queue_draw( wid);
 					}
 				} else
-					if ( Ch->upto < 18. ) {
-						Ch->from = Ch->from + .5;
-						Ch->upto = Ch->upto + .5;
-						Ch->get_power( false);
+					if ( Ch->psd.upto < 18. ) {
+						Ch->psd.from += .5;
+						Ch->psd.upto += .5;
+						Ch->get_psd_course( false);
+						if ( Ch->autoscale_profile )
+							Ch->update_profile_display_scales();
 						gtk_widget_queue_draw( wid);
 					}
-			    break;
+				break;
 			case GDK_SCROLL_LEFT:
 			case GDK_SCROLL_RIGHT:
-			    break;
+				break;
 			}
-
-		} else
+		else if ( event->state & GDK_SHIFT_MASK && event->state & GDK_MOD1_MASK && Ch->draw_mc )
 			switch ( event->direction ) {
 			case GDK_SCROLL_DOWN:
-				Ch->power_display_scale /= 1.1;
-				gtk_widget_queue_draw( wid);
-			    break;
+				if ( Ch->mc.bin > 0 ) {
+					--Ch->mc.bin;
+					Ch->get_mc_course( false);
+					if ( Ch->autoscale_profile )
+						Ch->update_profile_display_scales();
+					gtk_widget_queue_draw( wid);
+				}
+				break;
 			case GDK_SCROLL_UP:
-				Ch->power_display_scale *= 1.1;
-				gtk_widget_queue_draw( wid);
-			    break;
+				if ( Ch->mc.bin < Ch->crecording.sigfile::SMCParamSet::compute_n_bins(
+					     Ch->crecording.sigfile::CBinnedMC::samplerate()) - 1 ) {
+					++Ch->mc.bin;
+					Ch->get_mc_course( false);
+					if ( Ch->autoscale_profile )
+						Ch->update_profile_display_scales();
+					gtk_widget_queue_draw( wid);
+				}
+				break;
 			case GDK_SCROLL_LEFT:
-				if ( SF.cur_vpage() > 0 )
-					gtk_spin_button_set_value( SF.eSFCurrentPage,
-								   SF.cur_vpage() - 1);
-			    break;
 			case GDK_SCROLL_RIGHT:
-				if ( SF.cur_vpage() < SF.total_vpages() )
-					gtk_spin_button_set_value( SF.eSFCurrentPage,
-								   SF.cur_vpage() + 1);
-			    break;
+				break;
 			}
 
-		return TRUE;
+		else {
+			switch ( event->direction ) {
+			case GDK_SCROLL_DOWN:
+				Ch->psd.display_scale /= 1.1;
+				Ch->mc.display_scale /= 1.1;
+			    break;
+			case GDK_SCROLL_UP:
+				Ch->psd.display_scale *= 1.1;
+				Ch->mc.display_scale *= 1.1;
+			    break;
+			case GDK_SCROLL_LEFT:
+				if ( SF.cur_vpage() > 0 ) {
+					SF.set_cur_vpage( SF.cur_vpage() - 1);
+				}
+			    break;
+			case GDK_SCROLL_RIGHT:
+				if ( SF.cur_vpage() < SF.total_vpages() ) {
+					SF.set_cur_vpage( SF.cur_vpage() + 1);
+				}
+			    break;
+			}
+			if ( event->state & GDK_CONTROL_MASK )
+				for ( auto& H : SF.channels ) {
+					H.psd.display_scale = Ch->psd.display_scale;
+					H.mc.display_scale = Ch->mc.display_scale;
+				}
+			gtk_widget_queue_draw( wid);
+		}
+	} else {
+		switch ( event->direction ) {
+		case GDK_SCROLL_DOWN:
+			Ch->signal_display_scale /= 1.1;
+			break;
+		case GDK_SCROLL_UP:
+			Ch->signal_display_scale *= 1.1;
+			break;
+		default:
+			break;
+		}
+
+		if ( event->state & GDK_CONTROL_MASK )
+			for ( auto& H : SF.channels )
+				H.signal_display_scale = Ch->signal_display_scale;
+		gtk_widget_queue_draw( wid);
 	}
 
-	switch ( event->direction ) {
-	case GDK_SCROLL_DOWN:
-		Ch->signal_display_scale /= 1.1;
-	    break;
-	case GDK_SCROLL_UP:
-		Ch->signal_display_scale *= 1.1;
-	    break;
-	default:
-	    break;
-	}
-
-	if ( event->state & GDK_CONTROL_MASK )
-		for_each( SF.channels.begin(), SF.channels.end(),
-			  [&] ( SScoringFacility::SChannel& H)
-			  {
-				  H.signal_display_scale = Ch->signal_display_scale;
-			  });
-
-	gtk_widget_queue_draw( wid);
 	return TRUE;
 }
 
@@ -433,6 +469,8 @@ void
 iSFPageShowOriginal_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
 	SF.using_channel->draw_original_signal = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	// prevent both being switched off
 	if ( !SF.using_channel->draw_original_signal && !SF.using_channel->draw_filtered_signal )
@@ -446,6 +484,8 @@ void
 iSFPageShowProcessed_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
 	SF.using_channel->draw_filtered_signal = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	if ( !SF.using_channel->draw_filtered_signal && !SF.using_channel->draw_original_signal )
 		gtk_check_menu_item_set_active( SF.iSFPageShowOriginal,
@@ -458,6 +498,8 @@ void
 iSFPageUseResample_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
 	SF.using_channel->resample_signal = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
 }
@@ -467,6 +509,8 @@ void
 iSFPageDrawZeroline_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
 	SF.using_channel->draw_zeroline = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
 }
@@ -500,8 +544,10 @@ iSFPageShowHidden_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 	Ch->hidden = false;
 
 	SF.using_channel = Ch;
-	gtk_widget_get_pointer( (GtkWidget*)SF.daSFMontage,
-				NULL, (int*)&Ch->zeroy); //SF.find_free_space();
+	gdk_window_get_device_position(
+		gtk_widget_get_window( (GtkWidget*)SF.daSFMontage),
+		__pointer,
+		NULL, (int*)&Ch->zeroy, NULL); //SF.find_free_space();
 	SF.zeroy_before_shuffling = Ch->zeroy;
 	SF.event_y_when_shuffling = (double)Ch->zeroy;
 	SF.mode = aghui::SScoringFacility::TMode::shuffling_channels;
@@ -526,13 +572,38 @@ void
 iSFPageDrawPSDProfile_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
-	SF.using_channel->draw_power = (bool)gtk_check_menu_item_get_active( checkmenuitem);
+	if ( SF.suppress_redraw )
+		return;
+	SF.using_channel->draw_psd = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
 }
+
+void
+iSFPageDrawPSDSpectrum_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
+{
+	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
+	SF.using_channel->draw_spectrum = (bool)gtk_check_menu_item_get_active( checkmenuitem);
+	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
+}
+
+void
+iSFPageDrawMCProfile_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
+{
+	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
+	SF.using_channel->draw_mc = (bool)gtk_check_menu_item_get_active( checkmenuitem);
+	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
+}
+
 void
 iSFPageDrawEMGProfile_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
 	SF.using_channel->draw_emg = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
 }
@@ -553,8 +624,9 @@ iSFPageClearArtifacts_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 	SF.using_channel->get_signal_filtered();
 
 	if ( SF.using_channel->type == sigfile::SChannel::TType::eeg ) {
-		SF.using_channel->get_power( false);
-		SF.using_channel->get_power_in_bands( false);
+		SF.using_channel->get_psd_course( false);
+		SF.using_channel->get_psd_in_bands( false);
+		SF.using_channel->get_spectrum();
 	}
 
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
@@ -564,7 +636,7 @@ iSFPageClearArtifacts_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 
 
 void
-iSFPageSaveAs_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
+iSFPageSaveChannelAsSVG_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
 	auto& ED = SF._p;
@@ -575,8 +647,23 @@ iSFPageSaveAs_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 	SF.using_channel->draw_page( fname.c_str(), SF.da_wd, SF.interchannel_gap);
 	snprintf_buf( "Wrote \"%s\"",
 		      homedir2tilda(fname).c_str());
-	gtk_statusbar_pop( SF.sbSF, SF._p.sbContextIdGeneral);
-	gtk_statusbar_push( SF.sbSF, SF._p.sbContextIdGeneral, __buf__);
+	ED.buf_on_main_status_bar();
+}
+
+
+void
+iSFPageSaveMontageAsSVG_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
+{
+	auto& SF = *(SScoringFacility*)userdata;
+	auto& ED = SF._p;
+	string j_dir = ED.ED->subject_dir( SF.using_channel->crecording.subject());
+	snprintf_buf( "%s/%s/montage-p%zu@%zu.svg", j_dir.c_str(), ED.AghD(), SF.cur_vpage(), SF.vpagesize());
+	string fname {__buf__};
+
+	SF.draw_montage( fname.c_str());
+	snprintf_buf( "Wrote \"%s\"",
+		      homedir2tilda(fname).c_str());
+	ED.buf_on_main_status_bar();
 }
 
 
@@ -592,8 +679,7 @@ iSFPageExportSignal_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 	r.F().export_original( SF.using_channel->h(), __buf__);
 	snprintf_buf( "Wrote \"%s-{filt,orig}.tsv\"",
 		      fname_base.c_str());
-	gtk_statusbar_pop( SF.sbSF, SF._p.sbContextIdGeneral);
-	gtk_statusbar_push( SF.sbSF, SF._p.sbContextIdGeneral, __buf__);
+	SF._p.buf_on_main_status_bar();
 }
 
 
@@ -602,11 +688,11 @@ void
 iSFPageUseThisScale_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
-	SF.sane_signal_display_scale = SF.using_channel->signal_display_scale;
+	auto sane_signal_display_scale = SF.using_channel->signal_display_scale;
 	for_each( SF.channels.begin(), SF.channels.end(),
 		  [&] ( SScoringFacility::SChannel& H)
 		  {
-			  H.signal_display_scale = SF.sane_signal_display_scale;
+			  H.signal_display_scale = sane_signal_display_scale;
 		  });
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
 }
@@ -738,45 +824,83 @@ void
 iSFPowerExportRange_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
+	auto& R = SF.using_channel->crecording;
 
-	string fname_base = SF.using_channel->crecording.fname_base();
-	snprintf_buf( "%s_%g-%g.tsv",
-		      fname_base.c_str(), SF.using_channel->from, SF.using_channel->upto);
-	SF.using_channel->crecording.export_tsv( SF.using_channel->from, SF.using_channel->upto,
-						__buf__);
-	snprintf_buf( "Wrote %s_%g-%g.tsv",
-		      homedir2tilda(fname_base).c_str(), SF.using_channel->from, SF.using_channel->upto);
-	SF._p.buf_on_status_bar();
+	string fname_base;
+	if ( SF.using_channel->draw_psd ) {
+		fname_base = R.CBinnedPower::fname_base();
+		snprintf_buf( "%s-psd_%g-%g.tsv",
+			      fname_base.c_str(), SF.using_channel->psd.from, SF.using_channel->psd.upto);
+		R.CBinnedPower::export_tsv(
+			SF.using_channel->psd.from, SF.using_channel->psd.upto,
+			__buf__);
+		fname_base = __buf__; // recycle
+	}
+	if ( SF.using_channel->draw_mc ) {
+		fname_base = R.CBinnedMC::fname_base();
+		snprintf_buf( "%s-mc_%g-%g.tsv",
+			      fname_base.c_str(),
+			      R.freq_from + R.bandwidth*(SF.using_channel->mc.bin),
+			      R.freq_from + R.bandwidth*(SF.using_channel->mc.bin+1));
+		R.CBinnedMC::export_tsv(
+			SF.using_channel->mc.bin,
+			__buf__);
+		fname_base = __buf__;
+	}
+
+	snprintf_buf( "Wrote %s", homedir2tilda(fname_base).c_str());
+	SF._p.buf_on_main_status_bar();
 }
 
 void
 iSFPowerExportAll_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
-	auto& SF = *(SScoringFacility*)userdata;
+	const auto& SF = *(SScoringFacility*)userdata;
+	auto& R = SF.using_channel->crecording;
 
-	string fname_base = SF.using_channel->crecording.fname_base();
-	snprintf_buf( "%s_%g-%g.tsv",
-		      fname_base.c_str(), SF.using_channel->from, SF.using_channel->upto);
-	SF.using_channel->crecording.export_tsv( __buf__);
-	snprintf_buf( "Wrote %s_%g-%g.tsv",
-		      homedir2tilda(fname_base).c_str(), SF.using_channel->from, SF.using_channel->upto);
-	SF._p.buf_on_status_bar();
+	string fname_base;
+	if ( SF.using_channel->draw_psd ) {
+		fname_base = SF.using_channel->crecording.CBinnedPower::fname_base();
+		snprintf_buf( "%s-psd.tsv",
+			      fname_base.c_str());
+		R.CBinnedPower::export_tsv(
+			__buf__);
+		fname_base = __buf__; // recycle
+	}
+	if ( SF.using_channel->draw_mc ) {
+		fname_base = SF.using_channel->crecording.CBinnedMC::fname_base();
+		snprintf_buf( "%s-mc.tsv",
+			      fname_base.c_str());
+		R.CBinnedMC::export_tsv(
+			__buf__);
+		fname_base = __buf__;
+	}
+
+	snprintf_buf( "Wrote %s", homedir2tilda(fname_base).c_str());
+	SF._p.buf_on_main_status_bar();
 }
 
 void
 iSFPowerSmooth_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
-	SF.using_channel->resample_power = (bool)gtk_check_menu_item_get_active( checkmenuitem);
-	SF.using_channel->get_power(false);
-	SF.using_channel->get_power_in_bands(false);
-	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
+	if ( SF.suppress_redraw )
+		return;
+	if ( likely (SF.using_channel->type == sigfile::SChannel::TType::eeg ) ) {
+		SF.using_channel->resample_power = (bool)gtk_check_menu_item_get_active( checkmenuitem);
+		SF.using_channel->get_psd_course(false);
+		SF.using_channel->get_psd_in_bands(false);
+		SF.using_channel->get_mc_course( false);
+		gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
+	}
 }
 
 void
 iSFPowerDrawBands_toggled_cb( GtkCheckMenuItem *checkmenuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
 	SF.using_channel->draw_bands = (bool)gtk_check_menu_item_get_active( checkmenuitem);
 	gtk_widget_queue_draw( (GtkWidget*)SF.daSFMontage);
 }
@@ -786,12 +910,26 @@ iSFPowerUseThisScale_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
 
-	SF.sane_power_display_scale = SF.using_channel->power_display_scale;
-	for_each( SF.channels.begin(), SF.channels.end(),
-		  [&] ( SScoringFacility::SChannel& H)
-		  {
-			  H.power_display_scale = SF.sane_power_display_scale;
-		  });
+	auto	sane_psd_display_scale = SF.using_channel->psd.display_scale,
+		sane_mc_display_scale  = SF.using_channel->mc.display_scale;
+	for ( auto& H : SF.channels ) {
+		H.psd.display_scale = sane_psd_display_scale;
+		H.mc.display_scale  = sane_mc_display_scale;
+	}
+	SF.queue_redraw_all();
+}
+
+void
+iSFPowerAutoscale_toggled_cb( GtkCheckMenuItem *menuitem, gpointer userdata)
+{
+	auto& SF = *(SScoringFacility*)userdata;
+	if ( SF.suppress_redraw )
+		return;
+	auto& H = *SF.using_channel;
+
+	H.autoscale_profile = (bool)gtk_check_menu_item_get_active( menuitem);
+	printf( "set suppress_redraw %d\n", H.autoscale_profile);
+
 	SF.queue_redraw_all();
 }
 
