@@ -13,326 +13,20 @@
 
 
 
-#include <initializer_list>
 #include <stdexcept>
-#include <fstream>
 
-#include "../libexstrom/exstrom.hh"
-#include "../misc.hh"
-#include "../fs.hh"
+#include "../common/config-validate.hh"
+#include "../common/fs.hh"
 #include "misc.hh"
 #include "ui.hh"
-#include "expdesign.hh"
 #include "scoring-facility.hh"
 
 using namespace std;
 
 
 size_t	aghui::SScoringFacility::IntersignalSpace = 120,
-	aghui::SScoringFacility::HypnogramHeight = 80,
-	aghui::SScoringFacility::EMGProfileHeight = 30;
-
-
-
-void
-aghui::SScoringFacility::SChannel::compute_lowpass( float _cutoff, unsigned _order)
-{
-	if ( signal_lowpass.data.size() == 0 ||
-	     signal_lowpass.cutoff != _cutoff || signal_lowpass.order != _order )
-		signal_lowpass.data =
-			valarray<TFloat> (exstrom::low_pass( signal_filtered, samplerate(),
-							    signal_lowpass.cutoff = _cutoff,
-							    signal_lowpass.order = _order, true));
-}
-
-
-void
-aghui::SScoringFacility::SChannel::compute_tightness( unsigned _tightness)
-{
-	if ( signal_envelope.lower.size() == 0 ||
-	     signal_envelope.tightness != _tightness )
-		sigproc::envelope( signal_filtered,
-				   signal_envelope.tightness = _tightness, samplerate(),
-				   1./samplerate(),
-				   signal_envelope.lower,
-				   signal_envelope.upper); // don't need anchor points, nor their count
-}
-
-void
-aghui::SScoringFacility::SChannel::compute_dzcdf( float _step, float _sigma, unsigned _smooth)
-{
-	if ( signal_dzcdf.data.size() == 0 ||
-	     signal_dzcdf.step != _step || signal_dzcdf.sigma != _sigma || signal_dzcdf.smooth != _smooth )
-		signal_dzcdf.data =
-			sigproc::dzcdf<TFloat>( signal_filtered, samplerate(),
-						signal_dzcdf.step = _step,
-						signal_dzcdf.sigma = _sigma,
-						signal_dzcdf.smooth = _smooth);
-}
-
-
-
-list<sigfile::SAnnotation*>
-aghui::SScoringFacility::SChannel::in_annotations( double time) const
-{
-	// select this channel's annotations
-	auto& annotations = crecording.F().annotations(name);
-	list<sigfile::SAnnotation*>
-		ret;
-	size_t pos = time * crecording.F().samplerate(name);
-	for ( auto &A : annotations )
-		if ( overlap( A.span.first, A.span.second,
-			      pos, pos) )
-			ret.push_back( &A);
-	return ret;
-}
-
-
-void
-aghui::SScoringFacility::SChannel::get_power( bool force)
-{
-	auto tmp = (crecording.obtain_power( force),
-		    crecording.power_course<TFloat>( from, upto));
-	if ( resample_power ) {
-		auto xi = vector<size_t> (tmp.size());
-		for ( size_t i = 0; i < tmp.size(); ++i )
-			xi[i] = i;
-		power = sigproc::interpolate( xi, 3600/_p.pagesize(), tmp, 3./3600);
-	} else
-		power = tmp;
-}
-
-
-void
-aghui::SScoringFacility::SChannel::get_spectrum( size_t p)
-{
-	spectrum = crecording.power_spectrum<TFloat>( p);
-}
-void
-aghui::SScoringFacility::SChannel::get_power_in_bands( bool force)
-{
-	crecording.obtain_power( force);
-	if ( resample_power ) {
-		auto xi = vector<size_t> (crecording.n_pages());
-		for ( size_t i = 0; i < xi.size(); ++i )
-			xi[i] = i;
-		for ( size_t b = 0; b < (size_t)uppermost_band; ++b ) {
-			auto	_from = _p._p.freq_bands[b][0],
-				_upto = _p._p.freq_bands[b][1];
-			auto tmp = crecording.power_course<TFloat>( _from, _upto);
-			power_in_bands[b] =
-				sigproc::interpolate( xi, 3600/_p.pagesize(),
-						      tmp,
-						      3./3600);
-		}
-	} else
-		for ( size_t b = 0; b < (size_t)uppermost_band; ++b ) {
-			auto	_from = _p._p.freq_bands[b][0],
-				_upto = _p._p.freq_bands[b][1];
-			power_in_bands[b] =
-				crecording.power_course<TFloat>( _from, _upto);
-		}
-}
-
-
-// class SScoringFacility::SChannel
-
-aghui::SScoringFacility::SChannel::SChannel( agh::CRecording& r,
-					     SScoringFacility& parent,
-					     size_t y0)
-      : name (r.channel()),
-	type (r.signal_type()),
-	crecording (r),
-	filters (r.F().filters(name)),
-	annotations (r.F().annotations(name)),
-	artifacts (r.F().artifacts(name)),
-	_p (parent),
-	zeroy (y0),
-	hidden (false),
-	draw_zeroline (true),
-	draw_original_signal (false),
-	draw_filtered_signal (true),
-	zeromean_original (true),
-	draw_power (true),
-	draw_bands (true),
-	draw_spectrum_absolute (true),
-	resample_signal (true),
-	resample_power (true),
-	apply_reconstituted (false),
-	marquee_start (0.),
-	marquee_end (0.),
-	selection_start_time (0.),
-	selection_end_time (0.),
-	selection_start (0),
-	selection_end (0),
-	_h (crecording.F().channel_id(name))
-{
-	get_signal_original();
-	get_signal_filtered();
-
-	signal_display_scale =
-		calibrate_display_scale( signal_filtered,
-					 _p.vpagesize() * samplerate() * min (crecording.F().length(), (size_t)10),
-					 _p.interchannel_gap / 2);
-
-      // power and spectrum
-	if ( sigfile::SChannel::signal_type_is_fftable( type) ) {
-	      // power in a single bin
-		from = _p._p.operating_range_from;
-		upto = _p._p.operating_range_upto;
-		get_power( false);
-	      // power spectrum (for the first page)
-		n_bins = last_spectrum_bin = crecording.n_bins();
-		get_spectrum( 0);
-		// will be reassigned in REDRAW_ALL
-		spectrum_upper_freq = n_bins * crecording.bin_size;
-
-	      // power in bands
-		size_t n_bands = sigfile::TBand::delta;
-		while ( n_bands != sigfile::TBand::_total )
-			if ( _p._p.freq_bands[(size_t)n_bands][0] >= spectrum_upper_freq )
-				break;
-			else
-				++n_bands;
-		uppermost_band = (sigfile::TBand)(n_bands-1);
-		get_power_in_bands( false);
-
-	      // delta comes first, calibrate display scale against it
-		power_display_scale =
-			calibrate_display_scale( power_in_bands[sigfile::TBand::delta],
-						 power_in_bands[sigfile::TBand::delta].size(),
-						 _p.interchannel_gap/2.);
-	      // switches
-		draw_spectrum_absolute = true;
-		draw_bands = true;
-		focused_band = sigfile::TBand::delta;
-
-	} else if ( type == sigfile::SChannel::TType::emg ) {
-		valarray<TFloat> env_u, env_l;
-		sigproc::envelope( signal_original,
-				   5, samplerate(), 1.,
-				   env_l, env_u);
-		emg_profile.resize( env_l.size());
-		emg_profile = env_u - env_l;
-	}
-
-	percent_dirty = calculate_dirty_percent();
-
-
-      // widgetz!
-
-      // //expander and vbox
-	{
-		gchar *h_escaped = g_markup_escape_text( name, -1);
-		snprintf_buf( "%s <b>%s</b>",
-			      sigfile::SChannel::kemp_signal_types[type],
-			      h_escaped);
-		g_free( h_escaped);
-	}
-      // page view
-	;
-}
-
-aghui::SScoringFacility::SChannel::~SChannel()
-{
-}
-
-
-float
-__attribute__ ((pure))
-aghui::SScoringFacility::SChannel::calibrate_display_scale( const valarray<TFloat>& signal,
-							    size_t over, float fit)
-{
-	float max_over = 0.;
-	for ( size_t i = 0; i < over; ++i )
-		if ( max_over < signal[i] )
-			max_over = signal[i];
-	return fit / max_over;
-}
-
-
-float
-aghui::SScoringFacility::SChannel::calculate_dirty_percent()
-{
-	size_t total = 0; // in samples
-	auto& af = crecording.F().artifacts(_h);
-	for ( auto &A : af() )
-		total += A.second - A.first;
-	return percent_dirty = (float)total / n_samples();
-}
-
-
-
-
-void
-aghui::SScoringFacility::SChannel::mark_region_as_artifact( bool do_mark)
-{
-	if ( do_mark )
-		crecording.F().artifacts(_h).mark_artifact( selection_start, selection_end);
-	else
-		crecording.F().artifacts(_h).clear_artifact( selection_start, selection_end);
-
-	calculate_dirty_percent();
-
-	get_signal_filtered();
-
-	if ( type == sigfile::SChannel::TType::eeg ) {
-		get_power( false);
-		get_power_in_bands( false);
-		get_spectrum( _p.cur_page());
-	}
-	gtk_widget_queue_draw( (GtkWidget*)_p.daSFMontage);
-}
-
-void
-aghui::SScoringFacility::SChannel::mark_region_as_annotation( const char *label)
-{
-	crecording.F().annotations(_h).emplace_back( selection_start, selection_end,
-						     label);
-	gtk_widget_queue_draw( (GtkWidget*)_p.daSFMontage);
-}
-
-
-void
-aghui::SScoringFacility::SChannel::mark_region_as_pattern()
-{
-	_p.find_dialog.load_pattern( *this);
-	gtk_widget_show_all( (GtkWidget*)_p.find_dialog.wPattern);
-}
-
-
-
-void
-aghui::SScoringFacility::SChannel::update_channel_check_menu_items()
-{
-	gtk_check_menu_item_set_active( _p.iSFPageShowOriginal,
-					(gboolean)draw_original_signal);
-	gtk_check_menu_item_set_active( _p.iSFPageShowProcessed,
-					(gboolean)draw_filtered_signal);
-	gtk_check_menu_item_set_active( _p.iSFPageUseResample,
-					(gboolean)resample_signal);
-	gtk_check_menu_item_set_active( _p.iSFPageDrawZeroline,
-					(gboolean)draw_zeroline);
-
-	gtk_check_menu_item_set_active( _p.iSFPageDrawPSDProfile,
-					(gboolean)draw_power);
-	gtk_check_menu_item_set_active( _p.iSFPageDrawEMGProfile,
-					(gboolean)draw_emg);
-
-	gtk_widget_set_visible( (GtkWidget*)_p.iSFPageDrawPSDProfile,
-				type == sigfile::SChannel::TType::eeg);
-	gtk_widget_set_visible( (GtkWidget*)_p.iSFPageDrawEMGProfile,
-				type == sigfile::SChannel::TType::emg);
-}
-
-void
-aghui::SScoringFacility::SChannel::update_power_check_menu_items()
-{
-	gtk_check_menu_item_set_active( _p.iSFPowerDrawBands,
-					(gboolean)draw_bands);
-	gtk_check_menu_item_set_active( _p.iSFPowerSmooth,
-					(gboolean)resample_power);
-}
+	aghui::SScoringFacility::HypnogramHeight  =  40,
+	aghui::SScoringFacility::EMGProfileHeight =  30;
 
 
 // class aghui::SScoringFacility
@@ -344,7 +38,8 @@ const array<unsigned, 9>
 
 size_t
 __attribute__ ((pure))
-aghui::SScoringFacility::figure_display_pagesize_item( size_t seconds)
+aghui::SScoringFacility::
+figure_display_pagesize_item( size_t seconds)
 {
 	size_t i = 0;
 	while ( i < DisplayPageSizeValues.size()-1 && DisplayPageSizeValues[i] < seconds )
@@ -353,18 +48,19 @@ aghui::SScoringFacility::figure_display_pagesize_item( size_t seconds)
 }
 
 
-aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
-					   const string& D, const string& E,
-					   aghui::SExpDesignUI& parent)
+aghui::SScoringFacility::
+SScoringFacility( agh::CSubject& J,
+		  const string& D, const string& E,
+		  aghui::SExpDesignUI& parent)
       : _p (parent),
 	_csubject (J),
 	_session (D),
 	_sepisode (J.measurements.at(D)[E]),
-	ica (NULL),
+	ica (nullptr),
+	hypnogram_button_down (false),
 	mode (TMode::scoring),
 	crosshair_at (10),
 	draw_crosshair (false),
-	draw_spp (true),
 	alt_hypnogram (false),
 	pagesize_item (figure_display_pagesize_item( parent.pagesize())),
 	_cur_page (0),
@@ -372,10 +68,17 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 	skirting_run_per1 (.04),
 	interchannel_gap (IntersignalSpace),
 	n_hidden (0),
+	config_keys_b ({
+		confval::SValidator<bool>("draw.crosshair",	&draw_crosshair),
+		confval::SValidator<bool>("draw.alt_hypnogram",	&alt_hypnogram),
+	}),
+	config_keys_d ({
+		confval::SValidator<int>("interchannel_gap",	&interchannel_gap,	confval::SValidator<int>::SVFRangeIn (10, 400)),
+	}),
 	find_dialog (*this),
 	filters_dialog (*this),
 	phasediff_dialog (*this),
-	using_channel (NULL)
+	using_channel (nullptr)
 {
 	set_cursor_busy( true, (GtkWidget*)_p.wMainWindow);
 	gtk_widget_set_sensitive( (GtkWidget*)_p.wMainWindow, FALSE);
@@ -395,26 +98,27 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 	//  we do it all mostly ourself, except for some delete-event binding to gtk_true()
 
       // add channels, EEGs first, then EOG, EMG, then the rest
-	size_t y = interchannel_gap / 2.;
+	size_t	y = interchannel_gap / 2.;
+	char	seq = 'a';
 	for ( auto &H : _sepisode.recordings )
 		if ( H.second.signal_type() == sigfile::SChannel::TType::eeg ) {
-			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
-			_p.buf_on_status_bar();
-			channels.emplace_back( H.second, *this, y);
+			snprintf_buf( "Reading and processing EEG channel %s ...", H.first.c_str());
+			_p.buf_on_main_status_bar();
+			channels.emplace_back( H.second, *this, y, seq++);
 			y += interchannel_gap;
 		}
 	for ( auto &H : _sepisode.recordings )
 		if ( H.second.signal_type() == sigfile::SChannel::TType::eog ) {
-			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
-			_p.buf_on_status_bar();
-			channels.emplace_back( H.second, *this, y);
+			snprintf_buf( "Reading and processing EOG channel %s ...", H.first.c_str());
+			_p.buf_on_main_status_bar();
+			channels.emplace_back( H.second, *this, y, seq++);
 			y += interchannel_gap;
 		}
 	for ( auto &H : _sepisode.recordings )
 		if ( H.second.signal_type() == sigfile::SChannel::TType::emg ) {
-			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
-			_p.buf_on_status_bar();
-			channels.emplace_back( H.second, *this, y);
+			snprintf_buf( "Reading and processing EMG channel %s ...", H.first.c_str());
+			_p.buf_on_main_status_bar();
+			channels.emplace_back( H.second, *this, y, seq++);
 			y += interchannel_gap;
 		}
 	for ( auto &H : _sepisode.recordings ) {
@@ -423,8 +127,8 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 		     type != sigfile::SChannel::TType::eog &&
 		     type != sigfile::SChannel::TType::emg ) {
 			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
-			_p.buf_on_status_bar();
-			channels.emplace_back( H.second, *this, y);
+			_p.buf_on_main_status_bar();
+			channels.emplace_back( H.second, *this, y, seq++);
 			y += interchannel_gap;
 		}
 	}
@@ -432,37 +136,6 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 		throw invalid_argument( string ("No channels found for combination (") + J.name() + ", " + D + ", " + E + ")");
 	da_ht = montage_est_height();
 
-      // load montage
-	{
-		ifstream ifs (fs::make_fname_base( channels.front().crecording.F().filename(), ".edf", true) + ".montage");
-		if ( ifs.good() ) {
-			ifs >> draw_crosshair >> draw_spp
-			    >> sane_signal_display_scale >> sane_power_display_scale
-			    // >> skirting_run_per1
-			    >> interchannel_gap
-			    >> n_hidden
-			    >> alt_hypnogram;
-			for_each( channels.begin(), channels.end(),
-				  [&] ( SChannel& h)
-				  {
-					  // ofs >> h.name;
-					  ifs >> h.hidden
-					      >> h.draw_zeroline
-					      >> h.draw_original_signal
-					      >> h.draw_filtered_signal
-					      >> h.draw_power >> h.draw_bands
-					      >> h.resample_signal
-					      >> h.resample_power
-					      >> h.zeroy
-					      >> h.selection_start_time >> h.selection_end_time
-					      >> h.signal_display_scale >> h.power_display_scale >> h.emg_scale;
-					  h.selection_start = h.selection_start_time * h.samplerate();
-					  h.selection_end = h.selection_end_time * h.samplerate();
-				  });
-		}
-	}
-	// sane values, now set, will be used in SChannel ctors
-
       // histogram -> scores
 	get_hypnogram();
 	calculate_scored_percent();
@@ -475,26 +148,25 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 				  return h.type == sigfile::SChannel::TType::eeg;
 			  });
 
-      // recalculate (average) signal and power display scales
-	if ( isfinite( sane_signal_display_scale) ) {
-		;  // we've got it saved previously
-	} else {
-		sane_signal_display_scale = sane_power_display_scale = 0.;
-		size_t n_with_power = 0;
-		for ( auto &h : channels ) {
-			sane_signal_display_scale += h.signal_display_scale;
-			if ( h.type == sigfile::SChannel::TType::eeg ) {
-				++n_with_power;
-				sane_power_display_scale += h.power_display_scale;
-			}
-		}
-		sane_signal_display_scale /= channels.size();
-		sane_power_display_scale /= n_with_power;
-		for ( auto &h : channels ) {
-			h.signal_display_scale = sane_signal_display_scale;
-			if ( h.type == sigfile::SChannel::TType::eeg )
-				h.power_display_scale = sane_power_display_scale;
-		}
+      // load montage, recalibrate display scales as necessary
+	load_montage();
+
+	for ( auto &h : channels ) {
+		if ( not isfinite(h.signal_display_scale) || h.signal_display_scale <= 0. )
+			h.signal_display_scale =
+				h.calibrate_display_scale( h.signal_filtered,
+							   vpagesize() * h.samplerate() * min (h.crecording.F().pages(), (size_t)10),
+							   interchannel_gap / 2);
+		if ( not isfinite(h.psd.display_scale) || h.psd.display_scale <= 0. )
+			h.psd.display_scale =
+				h.calibrate_display_scale( h.psd.course_in_bands[sigfile::TBand::delta],
+							   h.psd.course.size(),
+							   interchannel_gap / 4);
+		if ( not isfinite(h.mc.display_scale) || h.mc.display_scale <= 0. )
+			h.mc.display_scale =
+				h.calibrate_display_scale( h.mc.course,
+							   h.mc.course.size(),
+							   interchannel_gap / 4);
 	}
 
       // set up other controls
@@ -543,6 +215,7 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 
 	// draw all
 	suppress_redraw = true;
+	suppress_set_vpage_from_cb = false;
 
 	repaint_score_stats();
 
@@ -555,7 +228,7 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 	g_signal_emit_by_name( eSFPageSize, "changed");
 
 	// tell main window we are done (so it can start another instance of scoring facility)
-	gtk_statusbar_pop( _p.sbMainStatusBar, _p.sbContextIdGeneral);
+	gtk_statusbar_pop( _p.sbMainStatusBar, _p.sbMainContextIdGeneral);
 
 	{
 		int bar_height;
@@ -589,7 +262,8 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 }
 
 
-aghui::SScoringFacility::~SScoringFacility()
+aghui::SScoringFacility::
+~SScoringFacility()
 {
 	if ( ica )
 		delete ica;
@@ -597,27 +271,8 @@ aghui::SScoringFacility::~SScoringFacility()
 	// put scores
 	put_hypnogram();
 
-	// save display scales
-	{
-		ofstream ofs (fs::make_fname_base( channels.front().crecording.F().filename(), ".edf", true) + ".montage");
-		if ( ofs.good() ) {
-			ofs << draw_crosshair << ' ' << draw_spp << ' '
-			    << sane_signal_display_scale << ' ' << sane_power_display_scale << ' '
-			    // << skirting_run_per1 << ' '
-			    << interchannel_gap << ' '
-			    << n_hidden << ' ' << alt_hypnogram << ' ' << endl;
-			for ( auto &H : channels )
-				ofs << H.hidden << ' '
-				    << H.draw_zeroline << ' ' << H.draw_original_signal << ' '
-				    << H.draw_filtered_signal << ' '
-				    << H.draw_power << ' ' << H.draw_bands << ' '
-				    << H.resample_signal << ' '
-				    << H.resample_power << ' '
-				    << H.zeroy << ' '
-				    << H.selection_start_time << ' ' << H.selection_end_time << ' '
-				    << H.signal_display_scale << ' ' << H.power_display_scale << ' ' << H.emg_scale << ' ' << endl;
-		}
-	}
+	// save montage
+	save_montage();
 
 	// destroy widgets
 	gtk_widget_destroy( (GtkWidget*)wScoringFacility);
@@ -638,21 +293,34 @@ aghui::SScoringFacility::~SScoringFacility()
 
 
 void
-aghui::SScoringFacility::get_hypnogram()
+aghui::SScoringFacility::
+update_all_channels_profile_display_scale()
+{
+	for ( auto& H : channels )
+		if ( sigfile::SChannel::signal_type_is_fftable( H.type) )
+			H.update_profile_display_scales();
+}
+
+
+
+void
+aghui::SScoringFacility::
+get_hypnogram()
 {
 	// just get from the first source,
 	// trust other sources are no different
 	auto &F = _sepisode.sources.front();
-	hypnogram.resize( F.sigfile::CHypnogram::length());
-	for ( size_t p = 0; p < F.length(); ++p )
+	hypnogram.resize( F.sigfile::CHypnogram::pages());
+	for ( size_t p = 0; p < F.pages(); ++p )
 		hypnogram[p] = F[p].score_code();
 }
 void
-aghui::SScoringFacility::put_hypnogram()
+aghui::SScoringFacility::
+put_hypnogram()
 {
 	// but put to all
 	for( auto &F : _sepisode.sources )
-		for ( size_t p = 0; p < F.sigfile::CHypnogram::length(); ++p )
+		for ( size_t p = 0; p < F.sigfile::CHypnogram::pages(); ++p )
 			F[p].mark( hypnogram[p]);
 }
 
@@ -660,7 +328,8 @@ aghui::SScoringFacility::put_hypnogram()
 
 
 void
-aghui::SScoringFacility::calculate_scored_percent()
+aghui::SScoringFacility::
+calculate_scored_percent()
 {
 	using namespace sigfile;
 	scored_percent_nrem =
@@ -688,7 +357,8 @@ aghui::SScoringFacility::calculate_scored_percent()
 
 
 size_t
-aghui::SScoringFacility::set_cur_page( size_t p)
+aghui::SScoringFacility::
+set_cur_page( size_t p)
 {
 	if ( p < total_pages() ) {
 		_cur_page = p;
@@ -698,17 +368,17 @@ aghui::SScoringFacility::set_cur_page( size_t p)
 	return _cur_page;
 }
 size_t
-aghui::SScoringFacility::set_cur_vpage( size_t p)
+aghui::SScoringFacility::
+set_cur_vpage( size_t p)
 {
 	if ( p < total_vpages() ) {
 		_cur_vpage = p;
 
 		if ( ap2p(p) != _cur_page ) { // vpage changed but page is same
 			_cur_page = ap2p(p);
-			// spectrum isn't displayed currently
-			// for ( auto H = channels.begin(); H != channels.end(); ++H )
-			// 	if ( H->draw_power && strcmp(H->type, "EEG") == 0 )
-			// 		H->spectrum = H->crecording.power_spectrum<TFloat>( _cur_page);
+			for ( auto& H : channels )
+				if ( H.type == sigfile::SChannel::TType::eeg && H.draw_spectrum )
+					H.get_spectrum( _cur_page);
 		}
 
 		// auto	cur_stage = cur_page_score();
@@ -729,7 +399,9 @@ aghui::SScoringFacility::set_cur_vpage( size_t p)
 		snprintf_buf( "<b>%s</b>", tmp);
 		gtk_label_set_markup( lSFClockTime, __buf__);
 
+		suppress_set_vpage_from_cb = true;
 		gtk_spin_button_set_value( eSFCurrentPage, _cur_vpage+1);
+		suppress_set_vpage_from_cb = false;
 
 		gtk_widget_set_sensitive( (GtkWidget*)bSFForward, _cur_vpage < total_vpages()-1);
 		gtk_widget_set_sensitive( (GtkWidget*)bSFBack, _cur_vpage > 0);
@@ -740,7 +412,8 @@ aghui::SScoringFacility::set_cur_vpage( size_t p)
 }
 
 void
-aghui::SScoringFacility::set_pagesize( int item)
+aghui::SScoringFacility::
+set_pagesize( int item)
 {
 	if ( item > (int)DisplayPageSizeValues.size() )
 		return;
@@ -748,7 +421,7 @@ aghui::SScoringFacility::set_pagesize( int item)
 	_cur_vpage = p2ap(_cur_page);
 
 	gtk_adjustment_set_upper( jPageNo, total_vpages());
-	gtk_spin_button_set_value( eSFCurrentPage, _cur_vpage+1);
+	set_cur_vpage( _cur_vpage+1);
 
 	gboolean sensitive_indeed = pagesize_is_right();
 	gtk_widget_set_sensitive( (GtkWidget*)(bScoreClear), sensitive_indeed);
@@ -770,15 +443,18 @@ aghui::SScoringFacility::set_pagesize( int item)
 
 
 void
-aghui::SScoringFacility::do_score_forward( char score_ch)
+aghui::SScoringFacility::
+do_score_forward( char score_ch)
 {
 	hypnogram[_cur_page] = score_ch;
 	calculate_scored_percent();
 	repaint_score_stats();
 	set_cur_page( _cur_page+1);
 }
+
 void
-aghui::SScoringFacility::do_score_back( char score_ch)
+aghui::SScoringFacility::
+do_score_back( char score_ch)
 {
 	hypnogram[_cur_page] = score_ch;
 	calculate_scored_percent();
@@ -787,7 +463,8 @@ aghui::SScoringFacility::do_score_back( char score_ch)
 }
 
 size_t
-aghui::SScoringFacility::SChannel::marquee_to_selection()
+aghui::SScoringFacility::SChannel::
+marquee_to_selection()
 {
 	if ( marquee_mstart < marquee_mend) {
 		marquee_start = marquee_mstart;
@@ -814,7 +491,8 @@ aghui::SScoringFacility::SChannel::marquee_to_selection()
 
 
 bool
-aghui::SScoringFacility::page_has_artifacts( size_t p)
+aghui::SScoringFacility::
+page_has_artifacts( size_t p)
 {
 	for ( auto &H : channels ) {
 		auto& Aa = H.crecording.F().artifacts(H._h)();
@@ -837,7 +515,8 @@ aghui::SScoringFacility::page_has_artifacts( size_t p)
 
 
 void
-aghui::SScoringFacility::repaint_score_stats() const
+aghui::SScoringFacility::
+repaint_score_stats() const
 {
 	snprintf_buf( "<b>%3.1f</b> %% scored", scored_percent);
 	gtk_label_set_markup( lSFPercentScored, __buf__);
@@ -853,7 +532,8 @@ aghui::SScoringFacility::repaint_score_stats() const
 }
 
 void
-aghui::SScoringFacility::queue_redraw_all() const
+aghui::SScoringFacility::
+queue_redraw_all() const
 {
 	if ( suppress_redraw )
 		return;
@@ -867,7 +547,8 @@ aghui::SScoringFacility::queue_redraw_all() const
 
 aghui::SScoringFacility::SChannel*
 __attribute__ ((pure))
-aghui::SScoringFacility::channel_near( int y)
+aghui::SScoringFacility::
+channel_near( int y)
 {
 	int nearest = INT_MAX, thisy;
 	SChannel* nearest_h = &channels.front();
@@ -901,15 +582,13 @@ struct SChHolder {
 };
 
 int
-aghui::SScoringFacility::find_free_space()
+aghui::SScoringFacility::
+find_free_space()
 {
 	vector<SChHolder> thomas;
-	for_each( channels.begin(), channels.end(),
-		  [&] (SChannel& ch)
-		  {
-			  if ( not ch.hidden )
-				  thomas.push_back( {ch});
-		  });
+	for ( SChannel& ch : channels )
+		if ( not ch.hidden )
+			thomas.push_back( {ch});
 	sort( thomas.begin(), thomas.end());
 
 	int	mean_gap,
@@ -935,7 +614,8 @@ aghui::SScoringFacility::find_free_space()
 }
 
 void
-aghui::SScoringFacility::space_evenly()
+aghui::SScoringFacility::
+space_evenly()
 {
 	vector<SChHolder> thomas;
 	for_each( channels.begin(), channels.end(),
@@ -967,11 +647,13 @@ aghui::SScoringFacility::space_evenly()
 
 
 void
-aghui::SScoringFacility::expand_by_factor( double fac)
+aghui::SScoringFacility::
+expand_by_factor( double fac)
 {
 	for ( auto &H : channels ) {
 		H.signal_display_scale *= fac;
-		H.power_display_scale *= fac;
+		H.psd.display_scale *= fac;
+		H.mc.display_scale *= fac;
 		H.zeroy *= fac;
 	}
 	interchannel_gap *= fac;
@@ -980,7 +662,8 @@ aghui::SScoringFacility::expand_by_factor( double fac)
 
 
 sigfile::SAnnotation*
-aghui::SScoringFacility::interactively_choose_annotation() const
+aghui::SScoringFacility::
+interactively_choose_annotation() const
 {
 	// do some on-the-fly construcion
 	gtk_combo_box_set_model( eAnnotationSelectorWhich, NULL);
@@ -997,29 +680,96 @@ aghui::SScoringFacility::interactively_choose_annotation() const
 	if ( GTK_RESPONSE_OK ==
 	     gtk_dialog_run( wAnnotationSelector) ) {
 		const char *selected_label = gtk_combo_box_get_active_id( eAnnotationSelectorWhich);
-		if ( selected_label == NULL )
-			return NULL;
+		if ( selected_label == nullptr )
+			return nullptr;
 		for ( auto &A : over_annotations )
 			if ( A->label == selected_label )
 				return A;
 	}
-	return NULL;
+	return nullptr;
 }
 
 
 
 
+
+
+
+
+
+
+void
+aghui::SScoringFacility::
+load_montage()
+{
+	libconfig::Config conf;
+	try {
+		conf.readFile ((fs::make_fname_base( channels.front().crecording.F().filename(), ".edf", true) + ".montage").c_str());
+	} catch (...) {
+		return;
+	}
+	confval::get( config_keys_b, conf);
+	confval::get( config_keys_d, conf);
+
+	for ( auto &h : channels ) {
+		confval::get( h.config_keys_b, conf);
+		confval::get( h.config_keys_d, conf);
+		confval::get( h.config_keys_g, conf);
+
+	      // postprocess a little
+		h.selection_start = h.selection_start_time * h.samplerate();
+		h.selection_end = h.selection_end_time * h.samplerate();
+
+	      // make sure these won't cause any confusion later
+		if ( h.type == sigfile::SChannel::TType::eeg )
+			h.draw_emg = false;
+		if ( h.type == sigfile::SChannel::TType::emg )
+			h.draw_psd = h.draw_mc = false;
+	}
+}
+
+
+
+void
+aghui::SScoringFacility::
+save_montage()
+{
+	libconfig::Config conf;
+	confval::put( config_keys_b, conf);
+	confval::put( config_keys_d, conf);
+
+	for ( auto &h : channels ) {
+		confval::put( h.config_keys_b, conf);
+		confval::put( h.config_keys_d, conf);
+		confval::put( h.config_keys_g, conf);
+	}
+	try {
+		conf.writeFile ((fs::make_fname_base( channels.front().crecording.F().filename(), ".edf", true) + ".montage").c_str());
+	} catch (...) {
+		;
+	}
+}
+
+void
+aghui::SScoringFacility::
+reset_montage()
+{
+	FAFA;
+}
+
+
 int
-aghui::SScoringFacility::construct_widgets()
+aghui::SScoringFacility::
+construct_widgets()
 {
 	GtkCellRenderer *renderer;
 
 	if ( !(AGH_GBGETOBJ3 (builder, GtkWindow,		wScoringFacility)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkLabel,		lSFHint)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkComboBox,		eSFPageSize)) ||
+	     !(AGH_GBGETOBJ3 (builder, GtkSpinButton,		eSFCurrentPage)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkAdjustment,		jPageNo)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkLabel,		lSFTotalPages)) ||
-	     !(AGH_GBGETOBJ3 (builder, GtkSpinButton,		eSFCurrentPage)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkLabel,		lSFClockTime)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkLabel,		lSFCurrentPos)) ||
 
@@ -1152,9 +902,12 @@ aghui::SScoringFacility::construct_widgets()
 	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem,	iSFPageUseResample)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem,	iSFPageDrawZeroline)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem, 	iSFPageDrawPSDProfile)) ||
+	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem, 	iSFPageDrawPSDSpectrum)) ||
+	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem, 	iSFPageDrawMCProfile)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem, 	iSFPageDrawEMGProfile)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPageFilter)) ||
-	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPageSaveAs)) ||
+	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPageSaveChannelAsSVG)) ||
+	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPageSaveMontageAsSVG)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPageExportSignal)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPageUseThisScale)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPageClearArtifacts)) ||
@@ -1176,6 +929,7 @@ aghui::SScoringFacility::construct_widgets()
 	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem,	iSFPowerSmooth)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem,	iSFPowerDrawBands)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFPowerUseThisScale)) ||
+	     !(AGH_GBGETOBJ3 (builder, GtkCheckMenuItem,	iSFPowerAutoscale)) ||
 
 	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFScoreAssist)) ||
 	     !(AGH_GBGETOBJ3 (builder, GtkMenuItem,		iSFScoreImport)) ||
@@ -1389,8 +1143,11 @@ aghui::SScoringFacility::construct_widgets()
 	g_signal_connect( iSFPageFilter, "activate",
 			  (GCallback)iSFPageFilter_activate_cb,
 			  this);
-	g_signal_connect( iSFPageSaveAs, "activate",
-			  (GCallback)iSFPageSaveAs_activate_cb,
+	g_signal_connect( iSFPageSaveChannelAsSVG, "activate",
+			  (GCallback)iSFPageSaveChannelAsSVG_activate_cb,
+			  this);
+	g_signal_connect( iSFPageSaveMontageAsSVG, "activate",
+			  (GCallback)iSFPageSaveMontageAsSVG_activate_cb,
 			  this);
 	g_signal_connect( iSFPageExportSignal, "activate",
 			  (GCallback)iSFPageExportSignal_activate_cb,
@@ -1411,6 +1168,12 @@ aghui::SScoringFacility::construct_widgets()
 	g_signal_connect( iSFPageDrawPSDProfile, "toggled",
 			  (GCallback)iSFPageDrawPSDProfile_toggled_cb,
 			  this);
+	g_signal_connect( iSFPageDrawPSDSpectrum, "toggled",
+			  (GCallback)iSFPageDrawPSDSpectrum_toggled_cb,
+			  this);
+	g_signal_connect( iSFPageDrawMCProfile, "toggled",
+			  (GCallback)iSFPageDrawMCProfile_toggled_cb,
+			  this);
 	g_signal_connect( iSFPageDrawEMGProfile, "toggled",
 			  (GCallback)iSFPageDrawEMGProfile_toggled_cb,
 			  this);
@@ -1431,6 +1194,9 @@ aghui::SScoringFacility::construct_widgets()
 	g_signal_connect( iSFPowerUseThisScale, "activate",
 			  (GCallback)iSFPowerUseThisScale_activate_cb,
 			  this);
+	g_signal_connect( iSFPowerAutoscale, "toggled",
+			  (GCallback)iSFPowerAutoscale_toggled_cb,
+			  this);
 
 
 	g_signal_connect( iSFScoreAssist, "activate",
@@ -1471,12 +1237,15 @@ aghui::SScoringFacility::construct_widgets()
 	g_signal_connect( daSFHypnogram, "draw",
 			  (GCallback)daSFHypnogram_draw_cb,
 			  this);
-	// g_signal_connect_after( daSFHypnogram, "configure-event",
-	// 			(GCallback)daSFHypnogram_configure_event_cb,
-	// 			this);
 	g_signal_connect( daSFHypnogram, "button-press-event",
 			  (GCallback)daSFHypnogram_button_press_event_cb,
 			  this);
+	g_signal_connect( daSFHypnogram, "button-release-event",
+			  (GCallback)daSFHypnogram_button_release_event_cb,
+			  this);
+	g_signal_connect( daSFHypnogram, "motion-notify-event",
+			  (GCallback)daSFHypnogram_motion_notify_event_cb,
+			  this);
 	return 0;
 }
 
@@ -1492,12 +1261,14 @@ const char* const
 	"  Alt+Move1:	move channel around\n"
 	"		in montage;\n"
 	" Alt+Wheel:	change montage height;\n"
-	" <i>on PSD:</i>\n"
+	" <i>on PSD/uC profile:</i>\n"
 	"  Click1:	position cursor;\n"
 	"  Click2:	bands/discrete 1Hz bins.\n"
-	"  Wheel:	cycle focused band\n"
+	"  Shift+Wheel:	cycle focused PSD band\n"
 	"		/ in-/decrement bin;\n"
-	"  Shift+Wheel:	in-/decrement scale.\n"
+	"  Shift+Alt+Wheel:\n"
+	"		in-/decrement uC bin;\n"
+	"  Wheel:	in-/decrement scale.\n"
 	"\n"
 	"<b>Hypnogram:</b>\n"
 	"  Click1:	position cursor;\n"
@@ -1511,10 +1282,5 @@ const char* const
 };
 
 
-
-
-
-
-
-// EOF
+// eof
 
