@@ -36,7 +36,8 @@ void
 eSFCurrentPage_value_changed_cb( GtkSpinButton *spinbutton, gpointer userdata)
 {
 	auto& SF = *(SScoringFacility*)userdata;
-	SF.set_cur_vpage( gtk_spin_button_get_value( SF.eSFCurrentPage) - 1);
+	if ( !SF.suppress_set_vpage_from_cb )
+		SF.set_cur_vpage( gtk_spin_button_get_value( spinbutton) - 1);
 }
 
 
@@ -61,7 +62,7 @@ bSFForward_clicked_cb( GtkButton *button, gpointer userdata)
 {
 	auto &SF = *(SScoringFacility*)userdata;
 	auto current = SF.cur_vpage();
-	if ( current < SF.total_vpages() )
+	if ( current < SF.total_vpages() - 1 )
 		SF.set_cur_vpage( ++current);
 }
 
@@ -70,7 +71,7 @@ bSFBack_clicked_cb( GtkButton *button, gpointer userdata)
 {
 	auto &SF = *(SScoringFacility*)userdata;
 	auto current = SF.cur_vpage();
-	if ( current >= 1 )
+	if ( current > 0 )
 		SF.set_cur_vpage( --current);
 }
 
@@ -191,13 +192,8 @@ bSFAccept_clicked_cb( GtkToolButton *button, gpointer userdata)
 {
 	auto SFp = (SScoringFacility*)userdata;
 
-	auto& JP = *SFp->_p.using_subject; // shorter than: = *SFp->subject_presentation_by_csubject(SFp->csubject());
-	delete JP.cscourse;
-	JP.cscourse = new agh::CSCourse (JP.csubject, SFp->session(), *SFp->_p._AghTi,
-					 SFp->_p.operating_range_from, SFp->_p.operating_range_upto,
-					 0., 0, false, false);
-
-	gtk_widget_queue_draw( (GtkWidget*)SFp->_p.cMeasurements);
+	SFp->_p.using_subject->create_cscourse();
+	gtk_widget_queue_draw( (GtkWidget*)SFp->_p.using_subject->da);
 
 	delete SFp;
 	// the resulting destruction of all widgets owned by SF will cause
@@ -211,26 +207,18 @@ iSFAcceptAndTakeNext_activate_cb( GtkMenuItem *menuitem, gpointer userdata)
 {
 	auto SFp = (SScoringFacility*)userdata;
 
-	auto& JP = *SFp->_p.using_subject;
-	delete JP.cscourse;
-	JP.cscourse = new agh::CSCourse (JP.csubject, SFp->session(), *SFp->_p._AghTi,
-					 SFp->_p.operating_range_from, SFp->_p.operating_range_upto,
-					 0., 0, false, false);
-
 	auto& ED = SFp->_p; // keep same parent
 
-	set_cursor_busy( true, (GtkWidget*)SFp->wScoringFacility);
-	const char
-		*j = SFp->channels.front().crecording.subject(),
-		*d = SFp->channels.front().crecording.session(),
-		*e = SFp->channels.front().crecording.episode();
-	agh::CSubject& J = ED.ED->subject_by_x(j);
+	ED.using_subject->create_cscourse();
+	gtk_widget_queue_draw( (GtkWidget*)ED.using_subject->da);
 
+	set_cursor_busy( true, (GtkWidget*)SFp->wScoringFacility);
 	// guaranteed to have next(E)
 
+	auto& J = SFp->csubject();
 	auto SFp2 = new SScoringFacility(
-		J, d,
-		next( J.measurements[d].episode_iter_by_name(e)) -> name(),
+		J, SFp->session().c_str(),
+		next( J.measurements[SFp->session()].episode_iter_by_name(SFp->sepisode().name())) -> name(),
 		ED);
 
 	delete SFp;
@@ -246,17 +234,11 @@ gboolean
 wScoringFacility_delete_event_cb( GtkWidget*, GdkEvent*, gpointer userdata)
 {
 	auto SFp = (SScoringFacility*)userdata;
+
+	SFp->_p.using_subject->create_cscourse();
+	gtk_widget_queue_draw( (GtkWidget*)SFp->_p.using_subject->da);
+
 	// not sure resurrection will succeed, tho
-
-	// lookup SSubjectPresentation
-	auto& JP = *SFp->_p.using_subject;
-	delete JP.cscourse;
-	JP.cscourse = new agh::CSCourse (JP.csubject, SFp->session(), *SFp->_p._AghTi,
-					 SFp->_p.operating_range_from, SFp->_p.operating_range_upto,
-					 0., 0, false, false);
-
-	gtk_widget_queue_draw( (GtkWidget*)SFp->_p.cMeasurements);
-
 	delete SFp;
 
 	return TRUE; // to stop other handlers from being invoked for the event
